/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-08-16, BG:   EP-731: Initial version of the revision history  **
** V1.0.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** ADC1: Display Poti position with LEDs, running ADC1 in ESM                 **
********************************************************************************
** The Poti voltage is read with ADC1-Ch8, measuring Ch8 in ESM.              **
** The CCU6-Timer13 is started by the MON1 pin and is used with a 1ms rate to **
** trigger the ESM.                                                           **
** The voltage measured on Ch8 is displayed in 6 intervals on the 5 LEDs.     **
*******************************************************************************/

#include "tle_device.h"

void Poti_Handler(void);


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */ 
  TLE_Init();

  /* Ensure MON Input is in release state (HIGH) */
  while (MONx_Debounce(1, MON_STATUS_HIGH) != MON_STATUS_HIGH);

  /* Check for MON = low to start CCU6 Timer13 */
  if (MONx_Debounce(1, MON_STATUS_LOW) == MON_STATUS_LOW)
  {
    /* Start the timer T13 in that case */
    CCU6_StartTmr_T13();
  }

  for (;;)
  {
    /* Main watchdog service */
    (void)WDT1_Service();
  }
}

/* Callback */
void Poti_Handler(void)
{
#define Interval_mV 833
  uint16 mV;
	bool value_valid;
  
	value_valid = ADC1_GetChResult_mV(&mV, ADC1_CH8);

  if (value_valid == true)
  {
    if (mV < 100u)
    {
      PORT_P02_Output_Low_Set();
    }
    if (mV > (1u * Interval_mV))
    {
      PORT_P02_Output_High_Set();
			PORT_P03_Output_Low_Set();
    }
    if (mV > (2u * Interval_mV))
    {
			PORT_P03_Output_High_Set();
			PORT_P04_Output_Low_Set();
    }
    if (mV > (3u * Interval_mV))
    {
			PORT_P04_Output_High_Set();
			PORT_P12_Output_Low_Set();
    }
    if (mV > (4u * Interval_mV))
    {
			PORT_P12_Output_High_Set();
			PORT_P14_Output_Low_Set();
    }
    if (mV > (5u * Interval_mV))
    {
			PORT_P14_Output_High_Set();
    }
  }
}
