/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-08-16, BG:   EP-731: Initial version of the revision history  **
** V1.0.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** ADC2: VS over-/undervoltage detection                                      **
********************************************************************************
** Enable VS over- and undervoltage interrupt.                                **
** LED8 (P0.2) will be on in case of VS undervoltage.                         **
** LED12 (P1.4)will be on in case of VS overvoltage.                          **
*******************************************************************************/
 
#include "tle_device.h"

void VS_Over_Voltage_Diag(void);
void VS_Under_Voltage_Diag(void);
void Diagnostic_Status_Clear(void);

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */ 
  TLE_Init();

  for (;;)
  {
    /* Main watchdog service */
    (void)WDT1_Service();
    Diagnostic_Status_Clear();
  }
}

/* Callback Function for ADC2 VS Upper Threshold Interrupt */
void VS_Over_Voltage_Diag(void)
{
	PORT_P14_Output_High_Set();
}

/* Callback Function for ADC2 VS Lower Threshold Interrupt */
void VS_Under_Voltage_Diag(void)
{
	PORT_P02_Output_High_Set();
}

void Diagnostic_Status_Clear(void)
{
  /* Clear VS overvoltage status */
  SCUPM->SYS_SUPPLY_IRQ_CLR.bit.VS_OV_SC = 1u;

  /* Status shows up again if overvoltage is still present: status remains clear if overvoltage is gone */
  if (SCUPM->SYS_SUPPLY_IRQ_STS.bit.VS_OV_STS == 0u)
  {
    /* If status stays clear then no more overvoltage condition: LED can be cleared */
		PORT_P14_Output_Low_Set();
  }

  /* Clear VS undervoltage status */
  SCUPM->SYS_SUPPLY_IRQ_CLR.bit.VS_UV_SC = 1u;

  /* Status shows up again if undervoltage is still present: status remains clear if undervoltage is gone */
  if (SCUPM->SYS_SUPPLY_IRQ_STS.bit.VS_UV_STS == 0u)
  {
    /* If status stays clear then no more undervoltage condition: LED can be cleared */
		PORT_P02_Output_Low_Set();
  }
}
