/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-08-16, BG:   EP-731: Initial version of the revision history  **
** V1.0.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** CCU6: Synchronisation of ADC1-EIM with CCU6 Ch0                            **
********************************************************************************
** Timer12 is running at a 50s period in center-aligned mode.                **
** The three compare channel have a compare match at:                         **
** Channel | DC  | CC6x | COUT6x                                              **
** -----------------------------                                              **
**   Ch0   |  n  | P0.4 | P0.5                                                **
**   Ch1   | 50% | P1.0 | P1.1                                                **
**   Ch2   | 10% | P0.1 | P1.4                                                **
**                                                                            **
** Timer12 (sync. to Ch0) triggers ADC1-Ch8 (Poti), which adjusts the duty    **
** cycle of Ch0.                                                              **
*******************************************************************************/

#include "tle_device.h"

void Poti_Handler(void);


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */ 
  TLE_Init();
  
  /* Start T12 */
  CCU6_StartTmr_T12();
  for (;;)
  {
    /* Main watchdog service */
    (void)WDT1_Service();
  }
}


/* Callback */
void Poti_Handler(void)
{
  uint16 cmp;
  uint16 mV;

  /* Get ADC1 EIM result in mV */
  ADC1_GetEIMResult_mV(&mV);
  cmp = CCU6_T12PR * mV / 5000;
  /* Ensure compare value is within valid range */
  if ((cmp > 0)&&(cmp < CCU6_T12PR))  
  {
    CCU6_LoadShadowRegister_CC60(cmp);
    CCU6_EnableST_T12();
		PORT_P12_Output_Toggle_Set();
  }
}
