/******************************************************************************
*                _  _               ___             _                         *
*               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\            *
*               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /            *
*               | || | | || |    / /_\\ | | | | | || |_) |/ __  /             *
*               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/              *
*                                                                             *
*    ihr GmbH                                                                 *
*    Airport Boulevard B210                                                   *
*    77836 Rheinmnster - Germany                                             *
*    http://www.ihr.de                                                        *
*    Phone +49(0) 7229-18475-0                                                *
*    Fax   +49(0) 7229-18475-11                                               *
*                                                                             *
*******************************************************************************
*                                                                             *
* (c) Alle Rechte bleiben bei IHR GmbH, auch fuer den Fall von Schutzrechts-  *
* anmeldungen. Jede Verfuegungsbefugnis, wie Kopier- und Weitergaberecht      *
* bleibt bei IHR GmbH.                                                        *
*                                                                             *
* (c) All rights reserved by IHR GmbH including the right to file             *
* industrial property rights. IHR GmbH retains the sole power of              *
* disposition such as reproduction or distribution.                           *
*                                                                             *
********************     Workfile:      lin_main.c       **********************
*                                                                             *
*  PROJECT-DESCRIPTION:  LIN Driver Protocol Layer                            *
*  FILE-DESCRIPTION:     Main routines for LIN driver                         *
*                                                                             *
*******************************************************************************
*                                                                             *
*       Revision:        $Rev:: 101         $                                 *
*       Responsible:     B.Roegl                                              *
*       Co-Responsible:  P.Koch                                               *
*       Last Modtime:    $Date:: 2016-03-08#$                                 *
*                                                                             *
******************************************************************************/
/**
@file lin_main.c
@brief Implementation of the Main Functionality inside the LIN Driver
*/

/* ===========================================================================
 *  Header files
 * ==========================================================================*/

#include "genLinConfig.h"
#include "lin_hal.h"
#include "lin_slave_task.h"
#include "lin_driver_api.h"

#include "lin_main.h"

/* ===========================================================================
 *  Global Variables
 * ==========================================================================*/

l_u8              g_lin_frame_index;
l_u8              g_lin_active_pid;
t_Lin_Frame_Ctrl  g_lin_frame_ctrl[LIN_NUMBER_OF_FRAMES];  /* init with const from the config file */
t_lin_prod_id     g_lin_prod_id;                           /* init with const from the config file */
t_lin_status_word g_lin_status_word;
l_irqmask         g_lin_irqState;
t_lin_rx_ctrl     g_lin_rx_ctrl;
l_u8              g_lin_frame_data_size;
#ifdef J2602_SLAVE
l_u8              j2602_broadcast_bytes[2][J2602_DNN_NUMBER_OF_BYTES];
#ifndef GM_SPEC_ADAPTION
l_u8              j2602_statusbyte = 0x00u;
#endif /* #ifndef GM_SPEC_ADAPTION */
#endif /* J2602_SLAVE */

#if ((defined LIN_MASTER)||(defined J2602_MASTER))
t_lin_sched_data  g_lin_sched_data;
l_u16             g_activeScheduleIdx;
l_u8              g_ScheduleFrmIdx;
l_u16             g_ScheduleIdx;
l_u16             g_sav_schedtab;
l_u8              g_sav_schedfrmidx;
l_u8              g_lin_zero_schedule;
l_u16             g_nextScheduleIdx;
l_u8              g_nextScheduleFrmIdx;
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */

/* ===========================================================================
 *  Functions
 * ==========================================================================*/

/* ---------------------------------------------------------------------------
 *  void lin_main_init(void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Initializes driver, calls HAL-init
   @param  void
   @retval void
*/
void lin_main_init(void)
{
   l_u8  loc_bytecounter = 0u;
   l_u8  loc_framecounter = 0u;

   /* init the Hardware */
   lin_hal_init();

   /* initialise general data settings */
#if ((defined(LIN_SLAVE)) || (defined(J2602_SLAVE)))
#ifdef LIN_INITIAL_NAD
   g_lin_prod_id.NAD = LIN_INITIAL_NAD;
   g_lin_prod_id.Initial_NAD = LIN_INITIAL_NAD;
#else
   g_lin_prod_id.NAD = l_callback_Get_Initial_NAD();
   g_lin_prod_id.Initial_NAD = l_callback_Get_Initial_NAD();
#endif /* end #ifdef LIN_INITIAL_NAD */
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1) || (defined J2602_PROTOCOL))
   g_lin_prod_id.Supplier_lo = LIN_SUPPLIER_ID_LO;
   g_lin_prod_id.Supplier_hi = LIN_SUPPLIER_ID_HI;
   g_lin_prod_id.Function_lo = LIN_FUNCTION_ID_LO;
   g_lin_prod_id.Function_hi = LIN_FUNCTION_ID_HI;
   g_lin_prod_id.Variant = LIN_VARIANT_ID;
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 */
#endif /* #if ((defined(LIN_SLAVE)) || (defined(J2602_SLAVE))) */

   g_lin_frame_index       = 0xFFu;
   g_lin_active_pid        = 0x0u;
   g_lin_status_word.reg   = 0u;
   g_lin_rx_ctrl.reg       = 0u;
   g_lin_irqState          = 0u;
   g_lin_frame_data_size   = 0u;

   /* initialize frame array*/
   for(loc_framecounter = 0u; loc_framecounter < LIN_NUMBER_OF_FRAMES; loc_framecounter++)
   {
#if ((defined LIN_ENABLE_ASSIGN_FRAME_ID) || (defined LIN_ENABLE_RBI_RD_MSG_ID_PID))
      for(loc_bytecounter = 0u; loc_bytecounter < 5u; loc_bytecounter++)
#else
      for(loc_bytecounter = 0u; loc_bytecounter < 3u; loc_bytecounter++)
#endif /* end #ifdef LIN_ENABLE_ASSIGN_FRAME_ID */
      {
         g_lin_frame_ctrl[loc_framecounter].reg[loc_bytecounter] = const_LIN_FRAME_CTRL_INIT[loc_framecounter].reg[loc_bytecounter];
      }
   }

   /* Initialize l_LinData with default data from the LDF file */
   for(loc_bytecounter = 0u; loc_bytecounter < (LIN_NUMBER_OF_FRAMES * 8u); loc_bytecounter++)
   {
         l_LinData.dataBytes[loc_bytecounter] = const_LinData.dataBytes[loc_bytecounter];
   }
#ifdef J2602_SLAVE
   g_j2602_status.reg[0] = 0u;
   /* Initialize buffers for broadcast message bytes */
   for(loc_bytecounter = 0u; loc_bytecounter < J2602_DNN_NUMBER_OF_BYTES; loc_bytecounter++)
   {
       j2602_broadcast_bytes[0][loc_bytecounter] = 0u;
       j2602_broadcast_bytes[1][loc_bytecounter] = 0u;
   }
#ifndef GM_SPEC_ADAPTION
   j2602_statusbyte = 0x00u;
#endif /* #ifndef GM_SPEC_ADAPTION */
   j2602_hal_target_reset (0u);
#endif /* end #ifdef J2602_SLAVE */

#if ((defined LIN_MASTER)||(defined J2602_MASTER))
   g_lin_zero_schedule = L_SET;
   Init_ScheduleTableList();
   lin_master_task_init();
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */
}

/* ---------------------------------------------------------------------------
 *  void l_get_byte_array(l_u8 start[], l_u8 count, l_u8 destination[])
 * --------------------------------------------------------------------------*/
/**
   @brief  Fetch a byte array
   @pre    LIN driver initialized
   @param  l_u8 start        source buffer
   @param  l_u8 count        number of bytes to be copied
   @param  l_u8 destination  target buffer
   @retval void
*/
/* (MISRA-C:2004 8.10/R, e765) external ... could be made static
 * Reason: Part of API, configuration dependent usage in signal access macros, MISRA violation can be issued. */
void l_get_byte_array(l_u8 start[], l_u8 count, l_u8 destination[])
{
   l_u8 loc_i;
   for(loc_i = 0u; loc_i < count; loc_i++)
   {
      destination[loc_i] = start[loc_i];
   }
}

/* ---------------------------------------------------------------------------
 *  void l_set_byte_array(l_u8 start[], l_u8 count, const l_u8 source[])
 * --------------------------------------------------------------------------*/
/**
   @brief  Set a byte array
   @pre    LIN driver initialized
   @param  l_u8 start        target buffer
   @param  l_u8 count        number of bytes to be copied
   @param  l_u8 source       source buffer
   @retval void
*/
/* (MISRA-C:2004 8.10/R, e765) external ... could be made static
 * Reason: Part of API, configuration dependent usage in signal access macros, MISRA violation can be issued. */
void l_set_byte_array(l_u8 start[], l_u8 count, const l_u8 source[])
{
   l_u8 loc_i;
   for(loc_i = 0u; loc_i < count; loc_i++)
   {
      start[loc_i] = source[loc_i];
   }
}

