/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

#include "linmain.h"
#include <Timer2x.h>

/*******************************************************************************
**                        Global Variable Declarations                        **
*******************************************************************************/
/* Global variables */
volatile unsigned char timer_250us, timer_1ms;
unsigned int BusIdleTimeOutCounter, tmpStatus;

/*******************************************************************************
**                         Global Function Definitions                        **
*******************************************************************************/

void LIN_LLD_Init(void)
{
		TIMER21_Start();

   /* LIN driver init */
   l_sys_init();
}

void LIN_LLD_Service(void)
{
		if (timer_250us)
		{
			 timer_250us = 0u;
			 /* cyclic communication task has to be called once every byte */
			 l_cyclic_com_task();
		}
		
		/* 1ms cyclic task */
		if (timer_1ms >= 4u)
		{
			 timer_1ms = 0u;
			 BusIdleTimeOutCounter++;

			 /* get status of lin driver from status word, see LIN specification 
					for more detailed information */
			 tmpStatus = l_ifc_read_status();

			/* If one of the statusflags is set then there was something on the bus
					reset counter and wake up */
			 if (tmpStatus & 0x00FFu)
			 {
					BusIdleTimeOutCounter = 0u;

			 }

			 /* After 4 seconds no communcation or other disturbtion - go to sleep */
			 if(BusIdleTimeOutCounter >= 4000u)
			 {
					BusIdleTimeOutCounter = 4000u; /* prevent overflow */
					
			 }   
			 
			 /* cyclic task of driver (timeout and diagnostic control */
			 ld_task();
		}
}

l_irqmask l_sys_irq_disable (void)
{
    l_irqmask ret = NVIC_GetEnableIRQ((IRQn_Type) LIN_UART_IR_SET_POS); 
    NVIC_DisableIRQ((IRQn_Type) CPU_NVIC_ICER_Int_UART1_Pos); 
    return ret; 
}

void l_sys_irq_restore (l_irqmask mask)
{
    if (mask) 
    {
        NVIC_EnableIRQ((IRQn_Type)LIN_UART_IR_SET_POS); 
    }
    return; 
}

void LIN_Enable_Transceiver(void)
{
    do {
        TRX->CTRL.bit.MODE = 3u;
    } while (TRX->CTRL.bit.MODE_FB != 7u);
    PMU->LIN_WAKE_EN.bit.LIN_EN = 0u;
}

void LIN_Disable_Transceiver(void)
{
    do {
        TRX->CTRL.bit.MODE = 0u;
    } while (TRX->CTRL.bit.MODE_FB != 1u);
    PMU->LIN_WAKE_EN.bit.LIN_EN = 1u;
}

void LIN_Task_250us(void)
{
		timer_250us++;
		timer_1ms++;
}

void LIN_COM_Handler(void)
{
#ifdef AUTOBAUD_ENABLED
   if (TIMER2->CON.bit.EXF2 == 1u)
   {
      l_ifc_t2();
      TIMER2->ICLR.bit.EXF2CLR = 1u;
   }
#endif /* end #ifdef AUTOBAUD_ENABLED */
   if ((UART1->SCON.reg & 0x01u) == 1u)
   {
      l_ifc_rx();
      UART1->SCONCLR.bit.RICLR = 1u;
   }
}
