/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** KC           Kay Claussen                                                  **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2015-08-07, DM:   Initial version                                  **
** V1.1.0: 2016-03-18, DM:   Added PORT                                       **
** V1.2.0: 2017-10-19, KC:   Moved device initialization into TLE_Init()      **
** V1.3.0: 2021-08-16, BG:   EP-731: Updated revision history layout          **
** V1.3.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
** V1.4.0: 2021-12-22, JO:   EP-971: Updated files linmain.c and lin_hal.c/h  **
**                           to handle NVIC_ISER/ICER registers correctly     **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** LIN: Slave example for LIN master-slave communication using two evalboards **
********************************************************************************
** LEDs indicate the communication between both devices.                      **
** LED_P1_4: MON1 button on master device was pushed; Low Side Relays 1 on    **
** both devices are enabled and disabled according to the LED                 **
** LED_P1_2: MON1 button on slave device was pushed; Low Side Relays 2 on     **
** both devices are enabled and disabled according to the LED                 **
*******************************************************************************/
 
#include "tle_device.h"
#include "linmain.h"

#define LED_P0_4 (0x04)
#define LED_P1_2 (0x12)
#define LED_P1_4 (0x14)

#define MON1_PUSHED_MASTER (0x4242)
#define MON1_PUSHED_SLAVE (0x2121)
#define LED_P1_2_OFF (0x2020)
#define LED_P1_4_OFF (0x4040)

uint16 speed = 0;

void MON1_pushed_CB(void);


int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */ 
  TLE_Init();

  /* Initialize LIN LLD */
  LIN_LLD_Init();
  
  for (;;)
  {
    /* Main watchdog service */
    (void)WDT1_Service();

    /* Handle LIN service */
    LIN_LLD_Service();
    
    /* Check for change in RefSpeed variable  */
    /* Value is sent via LIN by master device */
    if(l_flg_tst_RefSpeed())
    {
      speed = l_u16_rd_RefSpeed();
      /* Check if MON1 on master device has been pushed */
      if(speed == MON1_PUSHED_MASTER)
      {
        PORT_P14_Output_High_Set();
//        LS1_On();
      } /* Check if LED_P1_4 on master device has been switched off */
      else if(speed == LED_P1_4_OFF)
      {
        PORT_P14_Output_Low_Set();
//        LS1_Off();
      }
      else /* something else has been sent over LIN */
      {
        PORT_P04_Output_Toggle_Set();
      }
      l_flg_clr_RefSpeed();
    }
  }
}

/* Callback for pushing MON1 button */
void MON1_pushed_CB(void)
{
  /* check if LED_P1_2 is already active */
  if(PORT_P12_Get()) // PORT->P1_DATA.bit.PP2
  {
    PORT_P12_Output_Low_Set();
    
    /* send information of clearing of LED_P1_2 to master device and disable Low Side Relay 2 */
    l_u16_wr_ActSpeed(LED_P1_2_OFF);
    LS2_Off();
  }
  else
  {
    PORT_P12_Output_High_Set();
    
    /* send information of setting LED_P1_2 to master device and enable Low Side Relay 2 */
    l_u16_wr_ActSpeed(MON1_PUSHED_SLAVE);
    LS2_On();
  }
} 
