/******************************************************************************
*                _  _               ___             _                         *
*               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\            *
*               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /            *
*               | || | | || |    / /_\\ | | | | | || |_) |/ __  /             *
*               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/              *
*                                                                             *
*    ihr GmbH                                                                 *
*    Airport Boulevard B210                                                   *
*    77836 Rheinmnster - Germany                                             *
*    http://www.ihr.de                                                        *
*    Phone +49(0) 7229-18475-0                                                *
*    Fax   +49(0) 7229-18475-11                                               *
*                                                                             *
*******************************************************************************
*                                                                             *
* (c) Alle Rechte bleiben bei IHR GmbH, auch fuer den Fall von Schutzrechts-  *
* anmeldungen. Jede Verfuegungsbefugnis, wie Kopier- und Weitergaberecht      *
* bleibt bei IHR GmbH.                                                        *
*                                                                             *
* (c) All rights reserved by IHR GmbH including the right to file             *
* industrial property rights. IHR GmbH retains the sole power of              *
* disposition such as reproduction or distribution.                           *
*                                                                             *
********************     Workfile:      lin_main.h       **********************
*                                                                             *
*  PROJECT-DESCRIPTION:  LIN Driver Protocol Layer                            *
*  FILE-DESCRIPTION:     All defines for lin_main.c                           *
*                                                                             *
*******************************************************************************
*                                                                             *
*       Revision:        $Rev:: 101         $                                 *
*       Responsible:     B.Roegl                                              *
*       Co-Responsible:  P.Koch                                               *
*       Last Modtime:    $Date:: 2016-03-08#$                                 *
*                                                                             *
******************************************************************************/
/**
@file lin_main.h
@brief Header file of lin_main.c
*/

#ifndef LIN_MAIN_H /* to interpret header file only once */
#define LIN_MAIN_H

#include "genLinConfig.h"

/* ===========================================================================
 *  Constants
 * ==========================================================================*/

#ifndef L_SET
   #define L_SET                       1u
#endif /* end #ifdef L_SET */

#ifndef L_RESET
   #define L_RESET                     0u
#endif /* end #ifdef L_RESET */

#define PUBLISH                        1u
#define SUBSCRIBE                      0u


#define UNCONDITIONAL                  0u
#define LIN_2_X                        20u
#define LIN_1_3                        13u
#define J_2602                         2u

#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1) || (defined J2602_PROTOCOL))
   #define LIN_PROTOCOL_TYPE           20u
#else
   #define LIN_PROTOCOL_TYPE           13u
#endif

#define DIAG_FRAME_LENGTH              8u
#define SINGLE_FRAME                   ((l_u8)0x00)
#define FIRST_FRAME                    ((l_u8)0x10)
#define CONSECUTIVE_FRAME              ((l_u8)0x20)
#define NEG_RESPONSE_RSID              ((l_u8)0x7F)
#define RSID_OFFSET                    ((l_u8)0x40)
#define NRC_SubfunctionNotSupported    ((l_u8)0x12)
#define NRC_FunctionNotSupported       ((l_u8)0x10)


/* ===========================================================================
 *  Structures
 * ==========================================================================*/

/* ===========================================================================
 *  Function Prototypes
 * ==========================================================================*/

void lin_main_init(void);

/* ===========================================================================
 *  Variables
 * ==========================================================================*/

extern l_u8               g_lin_frame_index;
extern t_lin_prod_id      g_lin_prod_id;
extern t_Lin_Frame_Ctrl   g_lin_frame_ctrl[LIN_NUMBER_OF_FRAMES];
extern t_lin_status_word  g_lin_status_word;
extern l_u8               g_lin_active_pid;
extern t_lin_rx_ctrl      g_lin_rx_ctrl;
extern l_irqmask          g_lin_irqState;
extern l_u8               g_lin_frame_data_size;
#ifdef J2602_SLAVE
   extern l_u8               j2602_broadcast_bytes[2][J2602_DNN_NUMBER_OF_BYTES];
#endif /* end #ifdef J2602_SLAVE */
#if ((defined LIN_MASTER)||(defined J2602_MASTER))
extern t_lin_sched_data    g_lin_sched_data;
extern l_u16               g_activeScheduleIdx;
extern l_u8                g_ScheduleFrmIdx;
extern l_u8                g_nextScheduleFrmIdx;
extern l_u16               g_ScheduleIdx;
extern l_u16               g_sav_schedtab;
extern l_u8                g_sav_schedfrmidx;
extern l_u16               g_nextScheduleIdx;
extern l_u8                g_lin_zero_schedule;
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */

#endif /* end #ifndef LIN_MAIN_H */
