/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-08-16, BG:   EP-731: Initial version of the revision history  **
** V1.0.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** Flash: Program a page with RAM branching                                   **
********************************************************************************
** During the page programming, the function RAM_Branch_Function() is executed**
*******************************************************************************/

#include "tle_device.h"

/* allocate one flash page in RAM */
static uint8 TargetData[FlashPageSize];
static int32_t NVM_Result;

extern void RAM_Branch_Function(void);

int main(void)
{
  int i;

  /* Initialization of hardware modules based on Config Wizard configuration */ 
  TLE_Init();

  /* Fill up the TargetData array with housenumbers */
  for (i = 0; i < FlashPageSize; i++)
  {
    TargetData[i] = (uint8) i;
  }

  /* Call ProgramPage with the RAM BRANCH feature activated.
   * The function RAM_Branch_Function(void) will be called during the NVM operation. */
  /* Disable interrupts */
  __disable_irq();
  /* Service WDT1 short open window */
  WDT1_SOW_Service(1);
  /* Program NVM page */
  NVM_Result = user_nvm_write_branch(DataFlashStart, TargetData, FlashPageSize, 0, &RAM_Branch_Function);
  /* Main watchdog service: close short open window */
  (void)WDT1_Service();
  /* Enable interrupts */
  __enable_irq();

  /* Check if the programming worked fine */
  if (NVM_Result == ERR_LOG_SUCCESS)
  {
    /* Data in Data Flash page 0 correct */
    PORT_P14_Output_High_Set();
  }
  else
  {
    /* An error happened during ProgramPage */
    PORT_P12_Output_High_Set();
  }

  for (;;)
  {
    /* Main watchdog service */
    (void)WDT1_Service();
  }
}
