/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-08-16, BG:   EP-731: Initial version of the revision history  **
** V1.0.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** PMU: PowerSaving - StopMode                                                **
********************************************************************************
** Send the device into StopMode by pulling P1.0 to high.                     **
** Device wakes up by pressing MON1-4 button (configured by default) or       **
** Reset button. Observe VDDC reduction to ~0.9V.                             **
** LED_P1_4 on: Device is in normal operation mode.                           **
** LED_P1_2 on: Device is in stop mode.                                       **
*******************************************************************************/
 
#include "tle_device.h"

#define LED_P1_2 (0x12)
#define LED_P1_4 (0x14)

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */ 
  TLE_Init();
  
  while (1)
  {
    /* Main watchdog service */
    WDT1_Service();
    PORT_ChangePin(LED_P1_4, PORT_ACTION_SET);
    PORT_ChangePin(LED_P1_2, PORT_ACTION_CLEAR);

    if (PORT_ReadPin(0x10) == 1)
    {
      PORT_ChangePin(LED_P1_4, PORT_ACTION_CLEAR);
      PORT_ChangePin(LED_P1_2, PORT_ACTION_SET);
      /* Send the device into StopMode by pulling P1.0 to high */
      SCU_EnterStopMode();
    }
  }
}
