/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2021-08-16, BG:   EP-731: Initial version of the revision history  **
** V1.0.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** PMU: PowerSaving - SleepMode/StopMode with evaluation of Reset Status      **
********************************************************************************
** Send the device into SleepMode by pulling P1.1 to high or                  **
** send the device into StopMode by pulling P1.0 to high.                     **
** The device wakes up by MON (configured by default).                        **
** Check the LEDs on the evaluation board:                                    **
** - LED_P1_4 = POR                                                           **
** - LED_P1_2 = PIN Reset                                                     **
** - LED_P0_4 = Sleep Mode Exit                                               **
** - LED_P0_3 = Stop Mode Exit (exit with Reset only)                         **
** - LED_P0_2 = System Fail                                                   **
*******************************************************************************/

#include "tle_device.h"

void Evaluate_Reset_Source(void);

int main(void)
{
  /* Initialization of hardware modules based on Config Wizard configuration */ 
  TLE_Init();
  
  Evaluate_Reset_Source();
  for (;;)
  {
    /* Main watchdog service */
    (void)WDT1_Service();
    if (PORT_ReadPin(0x11) == 1)
    {
      /* Send the device into SleepMode by pulling P1.1 to high */
      SCU_EnterSleepMode();
    }
    if (PORT_ReadPin(0x10) == 1)
    {
      /* Send the device into StopMode by pulling P1.0 to high */
      SCU_EnterStopMode();
    }
  }
}

/** \brief Evaluate the Reset Status and turns on a LED per Reset source
 *
 * \param[in] None
 * \return none
 *
 * \ingroup main
 */
void Evaluate_Reset_Source(void)
{
  uint8 sts;

  sts = PMU_Get_Reset_Status();
  if (sts & PMU_RESET_STS_POR)
  {
    PORT_P14_Output_High_Set();
  }
  if (sts & PMU_RESET_STS_PIN)
  {
    PORT_P12_Output_High_Set();
  }
  if (sts & PMU_RESET_STS_SleepEx)
  {
    PORT_P04_Output_High_Set();
  }
  if (sts & PMU_RESET_STS_WAKE)
  {
    PORT_P03_Output_High_Set();
  }
  if (sts & PMU_RESET_STS_SYS_FAIL)
  {
    PORT_P02_Output_High_Set();
  }
  PMU_Clear_Reset_Status();
}
