/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/
/**
 * \file     system_tle984x.h
 *
 * \brief    System file for TLE984x
 *
 * \version  V1.2.3
 * \date     13. Dec 2021
 *
 * \note     This file is NOT MISRA compliant.
 *
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2014-10-08, xx:   Initial version                                  **
** V0.2.0: 2014-10-21, xx:   Editorial changes                                **
**                           Changed syntax for writing to memory             **
**                           Disabled NAC writing                             **
** V0.3.0: 2015-11-11, xx:   Extended SystemInit(), included epower_defines.h **
** V0.4.0: 2015-11-27, xx:   Added SCU_Init() to SystemInit() routine         **
** V0.5.0: 2016-05-03, xx:   Definition of BSL parameters adapted             **
** V0.6.0: 2016-06-28, xx:   SCU_Init removed from SystemInit()               **
** V1.1.0: 2017-10-19, xx:   Variable SystemFrequency removed                 **
**                           Version of this file must be greater than V1.0.0 **
**                           (pdsc)                                           **
** V1.1.1: 2019-04-05, xx:   Added SysTick_Init(); to SystemInit()            **
**                           Changed datatype of SystemFrequency from unsigned**
**                           int to uint32                                    **
**                           Added #include "types.h"                         **
** V1.2.0: 2021-02-26, BG:   EP-713: Added compatibility with IAR compiler    **
** V1.2.1: 2021-08-16, BG:   EP-731: Updated revision history layout          **
** V1.2.2: 2021-10-07, BG:   EP-931: Fixed NACNAD placement when using ARMCC  **
**                           v6 and LTO by adding attribute used              **
**                           Added #error Unsupported compiler! in case no    **
**                           supported compiler define is found               **
** V1.2.3: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

#ifndef __SYSTEM_TLE984x_H
#define __SYSTEM_TLE984x_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/
#include "types.h"

#ifdef __cplusplus
 extern "C" {
#endif 

/*******************************************************************************
**                        Global Variable Definitions                         **
*******************************************************************************/

extern uint32 SystemFrequency;    
extern const uint32 p_NACNAD;

/*******************************************************************************
**                         Global Function Declarations                       **
*******************************************************************************/

/** \brief Initialize the system and update the SystemFrequency variable
 */
extern void SystemInit (void);

#ifdef __cplusplus
}
#endif

#endif /* __SYSTEM_TLE984x_H */
