/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/**
 * \file     int.h
 *
 * \brief    Interrupt low level access library
 *
 * \version  V0.1.8
 * \date     13. Dec 2021
 *
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** AV           Axel Viebig                                                   **
** KC           Kay Claussen                                                  **
** TS           T&S                                                           **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2015-09-30, AV:   Initial version                                  **
** V0.1.1: 2015-11-21, AV:   Added SCUPM_SYS_IS to initialization             **
** V0.1.4: 2017-10-20, KC:   Macros for interrupt register access added       **
** V0.1.5: 2018-11-28, DM:   Macros formed into inline functions              **
**                           SFR bitfield accesses replaced by functions      **
**                           (Field_Mod(), ...)                               **
**                           DoxyGen docu added                               **
** V0.1.6: 2019-03-18, TS:   All positions for Field_X functions are cast     **
**                           with uint8                                       **
**                           INT_Clr_NMI_Status function updated              **
**                           INT_Init updated (WAKECON initialization added)  **
** V0.1.7: 2021-08-16, BG:   EP-731: Updated revision history layout          **
**                           Added inline functions declarations              **
**                           Moved DoxyGen documentation for global functions **
**                           to int.c                                         **
** V0.1.8: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

#ifndef INT_H
#define INT_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/

#include "tle984x.h"
#include "types.h"
#include "sfr_access.h"

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/

/**\brief NMI Flags selection macro, NMI_PLL */
#define NMI_PLL ((uint8)1u << 1u)
/**\brief NMI Flags selection macro, NMI_NVM */
#define NMI_NVM ((uint8)1u << 2u)
/**\brief NMI Flags selection macro, NMI_OT */
#define NMI_OT  ((uint8)1u << 3u)
/**\brief NMI Flags selection macro, NMI_OWT */
#define NMI_OWT ((uint8)1u << 4u)
/**\brief NMI Flags selection macro, NMI_MAP */
#define NMI_MAP ((uint8)1u << 5u)
/**\brief NMI Flags selection macro, NMI_ECC */
#define NMI_ECC ((uint8)1u << 6u)
/**\brief NMI Flags selection macro, NMI_SUP */
#define NMI_SUP ((uint8)1u << 7u)

/**\brief NMI Clear Bit Position */
#define SCU_NMISRCLR_Pos (0U)
/**\brief NMI Clear Bit Mask */
#define SCU_NMISRCLR_Msk (0xFFU)

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

void INT_Init(void);
INLINE void Global_Int_En(void);
INLINE void Global_Int_Dis(void);                             
INLINE void ECC_RAM_DoubleBit_Int_En(void);
INLINE void ECC_RAM_DoubleBit_Int_Dis(void);
INLINE void ECC_NVM_DoubleBit_Int_En(void);
INLINE void ECC_NVM_DoubleBit_Int_Dis(void);
INLINE void ECC_RAM_SingleBit_Int_Clr(void);
INLINE void ECC_RAM_DoubleBit_Int_Clr(void);
INLINE void ECC_NVM_DoubleBit_Int_Clr(void);
INLINE void EXINT0_Rising_Edge_Int_En(void);                  
INLINE void EXINT0_Rising_Edge_Int_Dis(void);                 
INLINE void EXINT0_Falling_Edge_Int_En(void);                 
INLINE void EXINT0_Falling_Edge_Int_Dis(void);                
INLINE void EXINT1_Rising_Edge_Int_En(void);                  
INLINE void EXINT1_Rising_Edge_Int_Dis(void);                 
INLINE void EXINT1_Falling_Edge_Int_En(void);                 
INLINE void EXINT1_Falling_Edge_Int_Dis(void);                
INLINE void EXINT2_Rising_Edge_Int_En(void);                  
INLINE void EXINT2_Rising_Edge_Int_Dis(void);                 
INLINE void EXINT2_Falling_Edge_Int_En(void);                 
INLINE void EXINT2_Falling_Edge_Int_Dis(void);                
INLINE void EXINT0_Rising_Edge_Int_Clr(void);
INLINE void EXINT0_Falling_Edge_Int_Clr(void);
INLINE void EXINT1_Rising_Edge_Int_Clr(void);
INLINE void EXINT1_Falling_Edge_Int_Clr(void);
INLINE void EXINT2_Rising_Edge_Int_Clr(void);
INLINE void EXINT2_Falling_Edge_Int_Clr(void);
INLINE void NMI_PLL_Int_En(void);
INLINE void NMI_PLL_Int_Dis(void);
INLINE void NMI_NVM_Int_En(void);
INLINE void NMI_NVM_Int_Dis(void);
INLINE void NMI_ECC_Int_En(void);
INLINE void NMI_ECC_Int_Dis(void);
INLINE void NMI_MAP_Int_En(void);
INLINE void NMI_MAP_Int_Dis(void);
INLINE void NMI_SUP_Int_En(void);
INLINE void NMI_SUP_Int_Dis(void);
INLINE void NMI_OWD_Int_En(void);
INLINE void NMI_OWD_Int_Dis(void);
INLINE void NMI_OT_Int_En(void);
INLINE void NMI_OT_Int_Dis(void);
INLINE void NMI_PLL_Int_Clr(void);
INLINE void NMI_NVM_Int_Clr(void);
INLINE void NMI_OT_Int_Clr(void);
INLINE void NMI_OWD_Int_Clr(void);
INLINE void NMI_MAP_Int_Clr(void);
INLINE void NMI_ECC_Int_Clr(void);
INLINE void NMI_SUP_Int_Clr(void);
INLINE uint8 INT_Get_NMI_Status(void);
INLINE void INT_Clr_NMI_Status(uint8 Flag);
INLINE void INT_Enable_Global_Int(void);
INLINE void INT_Disable_Global_Int(void);

/*******************************************************************************
**                     Global Inline Function Definitions                     **
*******************************************************************************/

/** \brief Enable Global Interrupt (Pending interrupt requests are not blocked from the core).
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Global Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   Global_Int_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void Global_Int_En(void)
{
	Field_Wrt32(&SCU->IEN0.reg, (uint8)SCU_IEN0_EA_Pos, SCU_IEN0_EA_Msk, 1u);
}

/** \brief Disable Global Interrupt (All pending interrupt requests,except NMI, are blocked from the core).
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Global Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   Global_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void Global_Int_Dis(void)                             
{
	Field_Wrt32(&SCU->IEN0.reg, (uint8)SCU_IEN0_EA_Pos, SCU_IEN0_EA_Msk, 0u);
} 

/** \brief Enable RAM Double Bit ECC Error Interrupt.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the RAM Double Bit ECC Error Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_ECC_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIECC == (uint8)1)
 *   {
 *     ECC_RAM_DoubleBit_Int_En();
 *     if ((uint8)SCU->EDCSTAT.bit.RDBE == (uint8)1)
 *     {
 *       SCU_ECC_RAM_DB_CALLBACK();
 *       ECC_RAM_DoubleBit_Int_Clr();
 *     } 
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void ECC_RAM_DoubleBit_Int_En(void)
{
  Field_Mod32(&SCU->EDCCON.reg, (uint8)SCU_EDCCON_RIE_Pos, SCU_EDCCON_RIE_Msk, 1u);
}

/** \brief Disable RAM Double Bit ECC Error Interrupt.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the RAM Double Bit ECC Error Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_ECC_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIECC == (uint8)1)
 *   {
 *     ECC_RAM_DoubleBit_Int_En();
 *     if ((uint8)SCU->EDCSTAT.bit.RDBE == (uint8)1)
 *     {
 *       SCU_ECC_RAM_DB_CALLBACK();
 *       ECC_RAM_DoubleBit_Int_Clr();
 *     } 
 *   }  
 *   ECC_RAM_DoubleBit_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void ECC_RAM_DoubleBit_Int_Dis(void)
{
  Field_Mod32(&SCU->EDCCON.reg, (uint8)SCU_EDCCON_RIE_Pos, SCU_EDCCON_RIE_Msk, 0u);
}

/** \brief Enable NVM Double Bit ECC Error Interrupt.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Double Bit ECC Error Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_ECC_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIECC == (uint8)1)
 *   {
 *     ECC_NVM_DoubleBit_Int_En();
 *     if ((uint8)SCU->EDCSTAT.bit.NVMDBE == (uint8)1)
 *     {
 *       SCU_ECC_NVM_DB_CALLBACK();
 *       ECC_NVM_DoubleBit_Int_Clr();
 *     }
 *   }  
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void ECC_NVM_DoubleBit_Int_En(void)
{
  Field_Mod32(&SCU->EDCCON.reg, (uint8)SCU_EDCCON_NVMIE_Pos, SCU_EDCCON_NVMIE_Msk, 1u);
}

/** \brief Disable NVM Double Bit ECC Error Interrupt.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Double Bit ECC Error Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_ECC_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIECC == (uint8)1)
 *   {
 *     ECC_NVM_DoubleBit_Int_En();
 *     if ((uint8)SCU->EDCSTAT.bit.NVMDBE == (uint8)1)
 *     {
 *       SCU_ECC_NVM_DB_CALLBACK();
 *       ECC_NVM_DoubleBit_Int_Clr();
 *     }
 *   }  
 *   ECC_NVM_DoubleBit_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void ECC_NVM_DoubleBit_Int_Dis(void)
{
  Field_Mod32(&SCU->EDCCON.reg, (uint8)SCU_EDCCON_NVMIE_Pos, SCU_EDCCON_NVMIE_Msk, 0u);
}

/** \brief Clear RAM Single Bit Error Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example checks the RAM Single Bit Error Status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   if ((uint8)SCU->EDCSTAT.bit.RSBE == (uint8)1)
 *   {
 *     ECC_RAM_SingleBit_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void ECC_RAM_SingleBit_Int_Clr(void)
{
  Field_Wrt32(&SCU->EDCSCLR.reg, (uint8)SCU_EDCSCLR_RSBEC_Pos, SCU_EDCSCLR_RSBEC_Msk, 1u);
}

/** \brief Clear RAM Double Bit ECC Error Interrupt flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the RAM Double Bit ECC Error Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   ECC_RAM_DoubleBit_Int_En();
 *   if ((uint8)SCU->EDCSTAT.bit.RDBE == (uint8)1)
 *   {
 *     SCU_ECC_RAM_DB_CALLBACK();
 *     ECC_RAM_DoubleBit_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void ECC_RAM_DoubleBit_Int_Clr(void)
{
  Field_Wrt32(&SCU->EDCSCLR.reg, (uint8)SCU_EDCSCLR_RDBEC_Pos, SCU_EDCSCLR_RDBEC_Msk, 1u);
}

/** \brief Clear NVM Double Bit ECC Error Interrupt flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Double Bit ECC Error Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   ECC_NVM_DoubleBit_Int_En();
 *   if ((uint8)SCU->EDCSTAT.bit.NVMDBE == (uint8)1)
 *   {
 *     SCU_ECC_NVM_DB_CALLBACK();
 *     ECC_NVM_DoubleBit_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void ECC_NVM_DoubleBit_Int_Clr(void)
{
  Field_Wrt32(&SCU->EDCSCLR.reg, (uint8)SCU_EDCSCLR_NVMDBEC_Pos, SCU_EDCSCLR_NVMDBEC_Msk, 1u);
}

/** \brief Enable Interrupt on rising edge at EXTINT0.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 0x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT0_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT0R == (uint8)1)
 *   {
 *     EXINT0_RISING_CALLBACK();
 *     EXINT0_Rising_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT0_Rising_Edge_Int_En(void)                  
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8) SCU_EXICON0_EXINT0_Pos, 0x01u , 1u);
}

/** \brief Disable Interrupt on rising edge at EXTINT0.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 0x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT0_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT0R == (uint8)1)
 *   {
 *     EXINT0_RISING_CALLBACK();
 *     EXINT0_Rising_Edge_Int_Clr();
 *   } 
 *   EXINT0_Rising_Edge_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT0_Rising_Edge_Int_Dis(void)                 
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8) SCU_EXICON0_EXINT0_Pos, 0x01u , 0u);
}

/** \brief Enable Interrupt on falling edge at EXTINT0.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 0x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT0_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT0F == (uint8)1)
 *   {
 *     EXINT0_FALLING_CALLBACK();
 *     EXINT0_Falling_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT0_Falling_Edge_Int_En(void)                 
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8)(SCU_EXICON0_EXINT0_Pos + 1u), 0x02u , 1u);
}

/** \brief Disable Interrupt on falling edge at EXTINT0.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 0x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT0_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT0F == (uint8)1)
 *   {
 *     EXINT0_FALLING_CALLBACK();
 *     EXINT0_Falling_Edge_Int_Clr();
 *   } 
 *   EXINT0_Falling_Edge_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT0_Falling_Edge_Int_Dis(void)                
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8)(SCU_EXICON0_EXINT0_Pos + 1u), 0x02u, 0u);
}

/** \brief Enable Interrupt on rising edge at EXTINT1.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 1x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT1_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT1R == (uint8)1)
 *   {
 *     EXINT1_RISING_CALLBACK();
 *     EXINT1_Rising_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT1_Rising_Edge_Int_En(void)                  
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8) SCU_EXICON0_EXINT1_Pos, 0x04u, 1u);
}

/** \brief Disable Interrupt on rising edge at EXTINT1.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 1x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT1_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT1R == (uint8)1)
 *   {
 *     EXINT1_RISING_CALLBACK();
 *     EXINT1_Rising_Edge_Int_Clr();
 *   } 
 *   EXINT1_Rising_Edge_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT1_Rising_Edge_Int_Dis(void)                 
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8) SCU_EXICON0_EXINT1_Pos, 0x04u, 0u);
}

/** \brief Enable Interrupt on falling edge at EXTINT1.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 1x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT1_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT1F == (uint8)1)
 *   {
 *     EXINT1_FALLING_CALLBACK();
 *     EXINT1_Falling_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT1_Falling_Edge_Int_En(void)                 
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8)(SCU_EXICON0_EXINT1_Pos + 1u), 0x08u, 1u);
}

/** \brief Disable Interrupt on falling edge at EXTINT1.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 1x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT1_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT1F == (uint8)1)
 *   {
 *     EXINT1_FALLING_CALLBACK();
 *     EXINT1_Falling_Edge_Int_Clr();
 *   } 
 *   EXINT1_Falling_Edge_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT1_Falling_Edge_Int_Dis(void)                
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8)(SCU_EXICON0_EXINT1_Pos + 1u), 0x08u, 0u);
}

/** \brief Enable Interrupt on rising edge at EXTINT2.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 2x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT2_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT2R == (uint8)1)
 *   {
 *     EXINT2_RISING_CALLBACK();
 *     EXINT2_Rising_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT2_Rising_Edge_Int_En(void)                  
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8) SCU_EXICON0_EXINT2_Pos, 0x10u, 1u);
}

/** \brief Disable Interrupt on rising edge at EXTINT2.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 2x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT2_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT2R == (uint8)1)
 *   {
 *     EXINT2_RISING_CALLBACK();
 *     EXINT2_Rising_Edge_Int_Clr();
 *   } 
 *   EXINT2_Rising_Edge_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT2_Rising_Edge_Int_Dis(void)                 
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8) SCU_EXICON0_EXINT2_Pos, 0x10u, 0u);
}

/** \brief Enable Interrupt on falling edge at EXTINT2.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 2x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT2_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT2F == (uint8)1)
 *   {
 *     EXINT2_FALLING_CALLBACK();
 *     EXINT2_Falling_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT2_Falling_Edge_Int_En(void)                 
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8)(SCU_EXICON0_EXINT2_Pos + 1u), 0x20u, 1u);
}

/** \brief Disable Interrupt on falling edge at EXTINT2.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 2x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT2_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT2F == (uint8)1)
 *   {
 *     EXINT2_FALLING_CALLBACK();
 *     EXINT2_Falling_Edge_Int_Clr();
 *   } 
 *   EXINT2_Falling_Edge_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT2_Falling_Edge_Int_Dis(void)                
{
	Field_Mod32(&SCU->EXICON0.reg, (uint8)(SCU_EXICON0_EXINT2_Pos + 1u), 0x20u, 0u);
}

/** \brief Clear Interrupt status on rising edge at EXTINT0.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 0x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT0_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT0R == (uint8)1)
 *   {
 *     EXINT0_RISING_CALLBACK();
 *     EXINT0_Rising_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT0_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON0CLR.reg, (uint8)SCU_IRCON0CLR_EXINT0RC_Pos, SCU_IRCON0CLR_EXINT0RC_Msk, 1u);
}

/** \brief Clear Interrupt status on falling edge at EXTINT0.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 0x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT0_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT0F == (uint8)1)
 *   {
 *     EXINT0_FALLING_CALLBACK();
 *     EXINT0_Falling_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT0_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON0CLR.reg, (uint8)SCU_IRCON0CLR_EXINT0FC_Pos, SCU_IRCON0CLR_EXINT0FC_Msk, 1u);
}

/** \brief Clear Interrupt status on rising edge at EXTINT1.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 1x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT1_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT1R == (uint8)1)
 *   {
 *     EXINT1_RISING_CALLBACK();
 *     EXINT1_Rising_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT1_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON0CLR.reg, (uint8)SCU_IRCON0CLR_EXINT1RC_Pos, SCU_IRCON0CLR_EXINT1RC_Msk, 1u);
}

/** \brief Clear Interrupt status on falling edge at EXTINT1.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 1x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT1_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT1F == (uint8)1)
 *   {
 *     EXINT1_FALLING_CALLBACK();
 *     EXINT1_Falling_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT1_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON0CLR.reg, (uint8)SCU_IRCON0CLR_EXINT1FC_Pos, SCU_IRCON0CLR_EXINT1FC_Msk, 1u);
}

/** \brief Clear Interrupt status on rising edge at EXTINT2.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 2x on rising edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT2_Rising_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT2R == (uint8)1)
 *   {
 *     EXINT2_RISING_CALLBACK();
 *     EXINT2_Rising_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT2_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON0CLR.reg, (uint8)SCU_IRCON0CLR_EXINT2RC_Pos, SCU_IRCON0CLR_EXINT2RC_Msk, 1u);
}

/** \brief Clear Interrupt status on falling edge at EXTINT2.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the External Interrupt 2x on falling edge.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   EXINT2_Falling_Edge_Int_En();
 *   if ((uint8)SCU->IRCON0.bit.EXINT2F == (uint8)1)
 *   {
 *     EXINT2_FALLING_CALLBACK();
 *     EXINT2_Falling_Edge_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void EXINT2_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON0CLR.reg, (uint8)SCU_IRCON0CLR_EXINT2FC_Pos, SCU_IRCON0CLR_EXINT2FC_Msk, 1u);
}

/** \brief Enable PLL Loss of Lock NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the PLL Loss of Lock NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_PLL_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIPLL == (uint8)1)
 *   {
 *     SCU_NMI_PLL_CALLBACK();
 *     NMI_PLL_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_PLL_Int_En(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIPLL_Pos, SCU_NMICON_NMIPLL_Msk, 1u);
}

/** \brief Disable PLL Loss of Lock NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the PLL Loss of Lock NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_PLL_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIPLL == (uint8)1)
 *   {
 *     SCU_NMI_PLL_CALLBACK();
 *     NMI_PLL_Int_Clr();
 *   } 
 *   NMI_PLL_Int_Dis(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_PLL_Int_Dis(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIPLL_Pos, SCU_NMICON_NMIPLL_Msk, 0u);
}

/** \brief Enable NVM Operation Complete NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Operation Complete NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_NVM_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMINVM == (uint8)1)
 *   {
 *     SCU_NMI_NVM_CALLBACK();
 *     NMI_NVM_Int_Clr();
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_NVM_Int_En(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMINVM_Pos, SCU_NMICON_NMINVM_Msk, 1u);
}

/** \brief Disable NVM Operation Complete NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Operation Complete NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_NVM_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMINVM == (uint8)1)
 *   {
 *     SCU_NMI_NVM_CALLBACK();
 *     NMI_NVM_Int_Clr();
 *   }
 *   NMI_NVM_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_NVM_Int_Dis(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMINVM_Pos, SCU_NMICON_NMINVM_Msk, 0u);
}

/** \brief Enable ECC Error NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the ECC Error NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_ECC_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIECC == (uint8)1)
 *   {
 *     NMI_ECC_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_ECC_Int_En(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIECC_Pos, SCU_NMICON_NMIECC_Msk, 1u);
}

/** \brief Disable ECC Error NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the ECC Error NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_ECC_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIECC == (uint8)1)
 *   {
 *     NMI_ECC_Int_Clr();
 *   } 
 *   NMI_ECC_Int_Dis(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_ECC_Int_Dis(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIECC_Pos, SCU_NMICON_NMIECC_Msk, 0u);
}

/** \brief Enable NVM Map Error NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Map Error NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_MAP_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIMAP == (uint8)1)
 *   {
 *     SCU_NMI_MAP_CALLBACK();
 *     NMI_MAP_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_MAP_Int_En(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIMAP_Pos, SCU_NMICON_NMIMAP_Msk, 1u);
}

/** \brief Disable NVM Map Error NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Map Error NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_MAP_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIMAP == (uint8)1)
 *   {
 *     SCU_NMI_MAP_CALLBACK();
 *     NMI_MAP_Int_Clr();
 *   } 
 *   NMI_MAP_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_MAP_Int_Dis(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIMAP_Pos, SCU_NMICON_NMIMAP_Msk, 0u);
}

/** \brief Enable Supply Prewarning NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the Supply Prewarning NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_SUP_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMISUP == (uint8)1)
 *   {
 *     NMI_SUP_Int_Clr();
 *   }
 * }
 * ~~~~~~~~~~~~~~~
 * \ingroup int_api
 */
INLINE void NMI_SUP_Int_En(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMISUP_Pos, SCU_NMICON_NMISUP_Msk, 1u);
}

/** \brief Disable Supply Prewarning NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the Supply Prewarning NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_SUP_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMISUP == (uint8)1)
 *   {
 *     NMI_SUP_Int_Clr();
 *   }
 *   NMI_SUP_Int_Dis(); 
 * }
 * ~~~~~~~~~~~~~~~
 * \ingroup int_api
 */
INLINE void NMI_SUP_Int_Dis(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMISUP_Pos, SCU_NMICON_NMISUP_Msk, 0u);
}

/** \brief Enable Oscillator Watchdog NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the Oscillator Watchdog NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_OWD_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIOWD == (uint8)1)
 *   {
 *     SCU_NMI_OWD_CALLBACK();
 *     NMI_OWD_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_OWD_Int_En(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIOWD_Pos, SCU_NMICON_NMIOWD_Msk, 1u);
}

/** \brief Disable Oscillator Watchdog NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the Oscillator Watchdog NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_OWD_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIOWD == (uint8)1)
 *   {
 *     SCU_NMI_OWD_CALLBACK();
 *     NMI_OWD_Int_Clr();
 *   } 
 *   NMI_OWD_Int_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_OWD_Int_Dis(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIOWD_Pos, SCU_NMICON_NMIOWD_Msk, 0u);
}

/** \brief Enable OT NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NMI OT.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_OT_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIOT == (uint8)1)
 *   {
 *     NMI_OT_Int_Clr();
 *   }
 * }
 * ~~~~~~~~~~~~~~~
 * \ingroup int_api
 */
INLINE void NMI_OT_Int_En(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIOT_Pos, SCU_NMICON_NMIOT_Msk, 1u);
}

/** \brief Disable OT NMI.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NMI OT.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_OT_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIOT == (uint8)1)
 *   {
 *     NMI_OT_Int_Clr();
 *   }
 *   NMI_OT_Int_Dis(); 
 * }
 * ~~~~~~~~~~~~~~~
 * \ingroup int_api
 */
INLINE void NMI_OT_Int_Dis(void)
{
  Field_Mod32(&SCU->NMICON.reg, (uint8)SCU_NMICON_NMIOT_Pos, SCU_NMICON_NMIOT_Msk, 0u);
}

/** \brief Clear PLL Loss of Lock NMI Flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the PLL Loss of Lock NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_PLL_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIPLL == (uint8)1)
 *   {
 *     SCU_NMI_PLL_CALLBACK();
 *     NMI_PLL_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_PLL_Int_Clr(void)
{
  Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_FNMIPLLC_Pos, SCU_NMISRCLR_FNMIPLLC_Msk, 1u);
}

/** \brief Clear NVM Operation Complete NMI flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Operation Complete NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_NVM_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMINVM == (uint8)1)
 *   {
 *     SCU_NMI_NVM_CALLBACK();
 *     NMI_NVM_Int_Clr();
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_NVM_Int_Clr(void)
{
  Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_FNMINVMC_Pos, SCU_NMISRCLR_FNMINVMC_Msk, 1u);
}

/** \brief Clear NMI OT Flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NMI OT.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_OT_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIOT == (uint8)1)
 *   {
 *     NMI_OT_Int_Clr();
 *   }
 * }
 * ~~~~~~~~~~~~~~~
 * \ingroup int_api
 */
INLINE void NMI_OT_Int_Clr(void)
{
  Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_FNMIOTC_Pos, SCU_NMISRCLR_FNMIOTC_Msk, 1u);
}

/** \brief Clear Oscillator Watchdog NMI Flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the Oscillator Watchdog NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_OWD_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIOWD == (uint8)1)
 *   {
 *     SCU_NMI_OWD_CALLBACK();
 *     NMI_OWD_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_OWD_Int_Clr(void)
{
  Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_FNMIOWDC_Pos, SCU_NMISRCLR_FNMIOWDC_Msk, 1u);
}

/** \brief Clear NVM Map Error NMI Flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the NVM Map Error NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_MAP_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIMAP == (uint8)1)
 *   {
 *     SCU_NMI_MAP_CALLBACK();
 *     NMI_MAP_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_MAP_Int_Clr(void)
{
  Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_FNMIMAPC_Pos, SCU_NMISRCLR_FNMIMAPC_Msk, 1u);
}

/** \brief Clear ECC Error NMI Flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the ECC Error NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_ECC_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMIECC == (uint8)1)
 *   {
 *     NMI_ECC_Int_Clr();
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void NMI_ECC_Int_Clr(void)
{
  Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_FNMIECCC_Pos, SCU_NMISRCLR_FNMIECCC_Msk, 1u);
}

/** \brief Clear Supply Prewarning NMI Flag.
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the Supply Prewarning NMI.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   NMI_SUP_Int_En();
 *   if ((uint8)SCU->NMISR.bit.FNMISUP == (uint8)1)
 *   {
 *     NMI_SUP_Int_Clr();
 *   }
 * }
 * ~~~~~~~~~~~~~~~
 * \ingroup int_api
 */
INLINE void NMI_SUP_Int_Clr(void)
{
  Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_FNMISUPC_Pos, SCU_NMISRCLR_FNMISUPC_Msk, 1u);
}

/** \brief Read out the NMI Status
 *
 * \return NMI status flags
 *
 * \brief <b>Example</b><br>
 * \brief This example Reads out the NMI Status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   uint8 val;
 *
 *   val = INT_Get_NMI_Status(); 
 * }
 * ~~~~~~~~~~~~~~~  
 * \ingroup int_api
 */
INLINE uint8 INT_Get_NMI_Status(void)
{
  return ((uint8) SCU->NMISR.reg);
}

/** \brief Clear the NMI Status flags
 *
 * \param Flag NMI Status bit mask
 *
 * \brief <b>Example</b><br>
 * \brief This example Clears All the NMI Status flags.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   INT_Clr_NMI_Status(0xFF); 
 * }
 * ~~~~~~~~~~~~~~~  
 * \ingroup int_api
 */
INLINE void INT_Clr_NMI_Status(uint8 Flag)
{
	Field_Wrt32(&SCU->NMISRCLR.reg, (uint8)SCU_NMISRCLR_Pos, SCU_NMISRCLR_Msk, Flag);
}

/** \brief Enable the global interrupt IEN0.EA
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Global Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   INT_Enable_Global_Int(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup int_api
 */
INLINE void INT_Enable_Global_Int(void)
{
  Global_Int_En();
}

/** \brief Disable the global interrupt IEN0.EA
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Global Interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   INT_Disable_Global_Int(); 
 * }
 * ~~~~~~~~~~~~~~~   
 * \ingroup int_api
 */
INLINE void INT_Disable_Global_Int(void)
{
  Global_Int_Dis();
}




#endif
