/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/**
 * \file     isr.h
 *
 * \brief    Interrupt Service Routines library
 *
 * \version  V0.2.6
 * \date     21. Dec 2021
 *
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** AV           Axel Viebig                                                   **
** KC           Kay Claussen                                                  **
** CE           Christian Engel                                               **
** TS           T&S                                                           **
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2015-10-23, AV:   Initial version                                  **
** V0.1.1: 2015-11-03, AV:   Changes for DU Measurements                      **
** V0.1.2: 2015-11-08, AV:   Corrected IRQS->IRQCLR in LS and HS section      **
** V0.1.3: 2015-11-20, AV:   LSx OT prewarn Interrupts removed (not on LSx    **
**                           nodes)                                           **
**                           Corrected naming in HS1 and HS2 section          **
**                           Rewritten whole NMI and ADC2 section             **
**                           Solved a problem that otherwise might block      **
**                           Supply NMI under certain conditions              **
** V0.1.4: 2015-11-27, AV:   Extended for MON5                                **
**                           Added HardFault ISR                              **
**                           EXINTx processing made compatible with XML       **
**                           implementation                                   **
**                           Corrected wrong documented (also in debugger)    **
**                           EXINTn Trigger select assignment (EXINT int.):   **
**                           0 (and not 3) is "Bypass Edge detection..."      **
**                           3 (and not 2) is "...both edges"                 **
**                           2 (and not 0) is "...fallig edge"                **
**                           Added LIN_SMERR_CALLBACK                         **
** V0.1.5: 2017-02-22, KC:   All ISRs: Interrupt enable checked at runtime    **
** V0.1.6: 2017-10-25, KC:   Names of Interrupt Clear Macros adapted          **
**                           XML Version Check enabled; Ext. Callbacks added  **
** V0.1.7: 2017-11-24, KC:   Interrupt clear for VBAT prewarning corrected    **
** V0.1.8: 2017-11-27, KC:   ADC1.ESM_STS bit needs to be cleared in interrupt**
** V0.1.9: 2018-11-05, CE:   Includes for "mon_defines.h" and "scu_defines.h" **
**                           added                                            **
**                           DoxyGen docu added                               **
** V0.2.0: 2019-03-18, TS:   All positions for Field_X functions are cast     **
**                           with uint8                                       **
**                           Unit Testing macro condition added               **
** V0.2.1: 2019-04-04, JO:   Added #include "pmu_defines.h" for WAKEUP ISR    **
**                           Removed Wakeup by Port0 and Port1 Pin3 ISR calls **
** V0.2.2: 2021-08-16, BG:   EP-731: Updated revision history layout          **
** V0.2.3: 2021-10-14, BG:   EP-915: Updated LIN -> TRX                       **
** V0.2.4: 2021-11-05, BG:   EP-970: Added functions to handle the LS{1/2}    **
**                           overtemperature prewarn interrupt                **
** V0.2.5: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
** V0.2.6: 2021-12-21, BG:   EP-997: Corrected MISRA 2012 violations          **
*******************************************************************************/

#ifndef ISR_H
#define ISR_H

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

/** \brief Interrupt Node 0, shared among GPT12E.T2, GPT12E.T3, GPT12E.T4
 *
 * \ingroup drv_api
 */
void GPT1_IRQHandler(void);

/** \brief Interrupt Node 1, shared among GPT12E.T5, GPT12E.T6, GPT12E.CAPREL
 *
 * \ingroup drv_api
 */
void GPT2_IRQHandler(void);

/** \brief Interrupt Node 2, for ADC2.VBG
 *
 * \ingroup drv_api
 */
void ADC2_IRQHandler(void);

/** \brief Interrupt Node 3, for ADC1
 *
 * \ingroup drv_api
 */
void ADC1_IRQHandler(void);

/** \brief Interrupt Node 4, Service Request 0 for CCU6
 *
 * \ingroup drv_api
 */
void CCU6SR0_IRQHandler(void);

/** \brief Interrupt Node 5, Service Request 1 for CCU6
 *
 * \ingroup drv_api
 */
void CCU6SR1_IRQHandler(void);

/** \brief Interrupt Node 6, Service Request 2 for CCU6
 *
 * \ingroup drv_api
 */
void CCU6SR2_IRQHandler(void);

/** \brief Interrupt Node 7, Service Request 3 for CCU6
 *
 * \ingroup drv_api
 */
void CCU6SR3_IRQHandler(void);

/** \brief Interrupt Node 8, for SSC1
 *
 * \ingroup drv_api
 */
void SSC1_IRQHandler(void);

/** \brief Interrupt Node 9, for SSC2
 *
 * \ingroup drv_api
 */
void SSC2_IRQHandler(void);

/** \brief Interrupt Node 10, shared among UART1, TIMER2 and LIN
 *
 * \ingroup drv_api
 */
void UART1_IRQHandler(void);

/** \brief Interrupt Node 11, shared among UART2, TIMER21 and Ext. Interrupt 2
 *
 * \ingroup drv_api
 */
void UART2_IRQHandler(void);

/** \brief Interrupt Node 12, for Ext. Interrupt 0
 *
 * \ingroup drv_api
 */
void EXINT0_IRQHandler(void);

/** \brief Interrupt Node 13, for Ext. Interrupt 1
 *
 * \ingroup drv_api
 */
void EXINT1_IRQHandler(void);

/** \brief Interrupt Node 14, for Wake up via GPIOs
 *
 * \ingroup drv_api
 */
void WAKEUP_IRQHandler(void);

/** \brief Interrupt Node 17, for Low Side Switch 1
 *
 * \ingroup drv_api
 */
void LS1_IRQHandler(void);

/** \brief Interrupt Node 18, for Low Side Switch 2
 *
 * \ingroup drv_api
 */
void LS2_IRQHandler(void);

/** \brief Interrupt Node 19, for High Side Switch 1
 *
 * \ingroup drv_api
 */
void HS1_IRQHandler(void);

/** \brief Interrupt Node 20, for High Side Switch 2
 *
 * \ingroup drv_api
 */
void HS2_IRQHandler(void);

/** \brief Interrupt Node 21, for Differential Unit
 *
 * \ingroup drv_api
 */
void DU_IRQHandler(void);

/** \brief Interrupt Node 22, for high voltage Monitor inputs
 *
 * \ingroup drv_api
 */
void MON_IRQHandler(void);

/** \brief Interrupt Node 23, for ADC1.Ch7..11
 *
 * \ingroup drv_api
 */
void PORT_IRQHandler(void);

/** \brief Exception Node for NMIs
 *
 * \ingroup drv_api
 */
void NMI_Handler(void);

/** \brief Exception Node for HardFault
 *
 * \ingroup drv_api
 */
void HardFault_Handler(void);

/** \brief Exception Node for SysTick
 *
 * \ingroup drv_api
 */
void SysTick_Handler(void);

#endif
