/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/**
 * \file     mon.h
 *
 * \brief    Monitor Input low level access library
 *
 * \version  V0.2.1
 * \date     13. Dec 2021
 *
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** DM           Daniel Mysliwitz                                              **
** AV           Axel Viebig                                                   **
** MK           Martin Kilian                                                 **
** KC           Kay Claussen                                                  **
** TS           T&S                                                           **
** BG           Blandine Guillot                                              **
** JO           Julia Ott                                                     **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2015-09-30, AV:   Initial version                                  **
** V0.1.1: 2015-11-23, AV:   Extended for MON5, MONx functions rewritten,     **
**                           Init extd.                                       **
** V0.1.2: 2016-06-28, DM:   Function name MON_Init renamed in MONx_Init      **
** V0.1.3: 2017-04-06, MK:   Added Macros for Register access                 **
** V0.1.6: 2017-06-20, KC:   Macros for interrupt register access added       **
** V0.1.7: 2018-11-28, DM:   Macros formed into inline functions              **
**                           SFR bitfield accesses replaced by functions      **
**                           (Field_Mod(), ...)                               **
**                           DoxyGen docu added                               **
** V0.1.8: 2019-03-18, TS:   All positions for Field_X functions are cast     **
**                           with uint8                                       **
** V0.1.9: 2021-08-16, BG:   EP-731: Updated revision history layout          **
**                           Added inline functions declarations              **
**                           Moved DoxyGen documentation for global functions **
**                           to mon.c                                         **
** V0.2.0: 2021-10-07, BG:   EP-931: Corrected ARMCC compiler v6 errors       **
** V0.2.1: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

#ifndef MON_H
#define MON_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/

#include "tle984x.h"
#include "tle_variants.h"
#include "types.h"
#include "sfr_access.h"

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/

/* MON Status Flag */
/**\brief MON Status Flag mask, MON LOW STATUS */
#define MON_STATUS_LOW  (0U)
/**\brief MON Status Flag mask, MON HIGH STATUS */
#define MON_STATUS_HIGH (1U)

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

void  MONx_Init(void);
uint8 MONx_Get_Status(uint8 Monx);
uint8 MONx_Debounce(uint8 Monx,uint8 MonActiveState);
INLINE void MON1_Rising_Edge_Int_Clr(void);
INLINE void MON1_Falling_Edge_Int_Clr(void);
INLINE void MON2_Rising_Edge_Int_Clr(void);
INLINE void MON2_Falling_Edge_Int_Clr(void);
INLINE void MON3_Rising_Edge_Int_Clr(void);
INLINE void MON3_Falling_Edge_Int_Clr(void);
INLINE void MON4_Rising_Edge_Int_Clr(void);
INLINE void MON4_Falling_Edge_Int_Clr(void);
INLINE void MON5_Rising_Edge_Int_Clr(void);
INLINE void MON5_Falling_Edge_Int_Clr(void);
INLINE void MON1_Int_En(void);
INLINE void MON2_Int_En(void);
INLINE void MON3_Int_En(void);
INLINE void MON4_Int_En(void);
INLINE void MON5_Int_En(void);
INLINE void MON1_Int_Dis(void);
INLINE void MON2_Int_Dis(void);
INLINE void MON3_Int_Dis(void);
INLINE void MON4_Int_Dis(void);
INLINE void MON5_Int_Dis(void);
INLINE uint8 MON4_Sts(void);
INLINE void MON4_PullUp_En(void);
INLINE void MON4_PullUp_Dis(void);
INLINE void MON4_PullDown_En(void);
INLINE void MON4_PullDown_Dis(void);
INLINE void MON4_CycSense_En(void);
INLINE void MON4_CycSense_Dis(void);
INLINE void MON4_WakeOnRise_En(void);
INLINE void MON4_WakeOnRise_Dis(void);
INLINE void MON4_WakeOnFall_En(void);
INLINE void MON4_WakeOnFall_Dis(void);
INLINE void MON4_En(void);
INLINE void MON4_Dis(void);
INLINE uint8 MON3_Sts(void);
INLINE void MON3_PullUp_En(void);
INLINE void MON3_PullUp_Dis(void);
INLINE void MON3_PullDown_En(void);
INLINE void MON3_PullDown_Dis(void);
INLINE void MON3_CycSense_En(void);
INLINE void MON3_CycSense_Dis(void);
INLINE void MON3_WakeOnRise_En(void);
INLINE void MON3_WakeOnRise_Dis(void);
INLINE void MON3_WakeOnFall_En(void);
INLINE void MON3_WakeOnFall_Dis(void);
INLINE void MON3_En(void);
INLINE void MON3_Dis(void);
INLINE uint8 MON2_Sts(void);
INLINE void MON2_PullUp_En(void);
INLINE void MON2_PullUp_Dis(void);
INLINE void MON2_PullDown_En(void);
INLINE void MON2_PullDown_Dis(void);
INLINE void MON2_CycSense_En(void);
INLINE void MON2_CycSense_Dis(void);
INLINE void MON2_WakeOnRise_En(void);
INLINE void MON2_WakeOnRise_Dis(void);
INLINE void MON2_WakeOnFall_En(void);
INLINE void MON2_WakeOnFall_Dis(void);
INLINE void MON2_En(void);
INLINE void MON2_Dis(void);
INLINE uint8 MON1_Sts(void);
INLINE void MON1_PullUp_En(void);
INLINE void MON1_PullUp_Dis(void);
INLINE void MON1_PullDown_En(void);
INLINE void MON1_PullDown_Dis(void);
INLINE void MON1_CycSense_En(void);
INLINE void MON1_CycSense_Dis(void);
INLINE void MON1_WakeOnRise_En(void);
INLINE void MON1_WakeOnRise_Dis(void);
INLINE void MON1_WakeOnFall_En(void);
INLINE void MON1_WakeOnFall_Dis(void);
INLINE void MON1_En(void);
INLINE void MON1_Dis(void);
#if (UC_FEAT_MON == 5u)
INLINE uint8 MON5_Sts(void);
INLINE void MON5_PullUp_En(void);
INLINE void MON5_PullUp_Dis(void);
INLINE void MON5_PullDown_En(void);
INLINE void MON5_PullDown_Dis(void);
INLINE void MON5_CycSense_En(void);
INLINE void MON5_CycSense_Dis(void);
INLINE void MON5_WakeOnRise_En(void);
INLINE void MON5_WakeOnRise_Dis(void);
INLINE void MON5_WakeOnFall_En(void);
INLINE void MON5_WakeOnFall_Dis(void);
INLINE void MON5_En(void);
INLINE void MON5_Dis(void);
#endif

/*******************************************************************************
**                     Global Inline Function Definitions                     **
*******************************************************************************/

/* MONx Interrupt Clear */
/** \brief Clear MON1 on rising edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON1 on rising edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON1_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 0u)) != 0u)
 *   {
 *     if ((uint8)SCU->IRCON1.bit.MON1R == (uint8)1)
 *     {
 *       MON1_RISING_CALLBACK();
 *       MON1_Rising_Edge_Int_Clr();
 *     }
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON1RC_Pos, SCU_IRCON1CLR_MON1RC_Msk, 1u);
}

/** \brief Clear MON1 on falling edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON1 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON1_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 1u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON1F == (uint8)1)
 *     {
 *       MON1_FALLING_CALLBACK();
 *       MON1_Falling_Edge_Int_Clr();
 *     } 
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON1FC_Pos, SCU_IRCON1CLR_MON1FC_Msk, 1u);
}

/** \brief Clear MON2 on rising edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON2 on rising edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON2_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 2u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON2R == (uint8)1)
 *     {
 *       MON2_RISING_CALLBACK();
 *       MON2_Rising_Edge_Int_Clr();
 *     }
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON2RC_Pos, SCU_IRCON1CLR_MON2RC_Msk, 1u);
}

/** \brief Clear MON2 on falling edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON2 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON2_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 3u)) != 0u)
 *   { 	 
 *     if ((uint8)SCU->IRCON1.bit.MON2F == (uint8)1)
 *     {
 *       MON2_FALLING_CALLBACK();
 *       MON2_Falling_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON2FC_Pos, SCU_IRCON1CLR_MON2FC_Msk, 1u);
}

/** \brief Clear MON3 on rising edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON3 on rising edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON3_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 4u)) != 0u)
 *   { 	 
 *     if ((uint8)SCU->IRCON1.bit.MON3R == (uint8)1)
 *     {
 *       MON3_RISING_CALLBACK();
 *       MON3_Rising_Edge_Int_Clr();
 *     }
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON3RC_Pos, SCU_IRCON1CLR_MON3RC_Msk, 1u);
}

/** \brief Clear MON3 on falling edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON3 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON3_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 5u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON3F == (uint8)1)
 *     {
 *       MON3_FALLING_CALLBACK();
 *       MON3_Falling_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON3FC_Pos, SCU_IRCON1CLR_MON3FC_Msk, 1u);
}

/** \brief Clear MON4 on rising edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON4 on rising edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON4_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 6u)) != 0u)
 *   {
 *     if ((uint8)SCU->IRCON1.bit.MON4R == (uint8)1)
 *     {
 *       MON4_RISING_CALLBACK();
 *       MON4_Rising_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON4RC_Pos, SCU_IRCON1CLR_MON4RC_Msk, 1u);
}

/** \brief Clear MON4 on falling edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON4 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON4_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 7u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON4F == (uint8)1)
 *     {
 *       MON4_FALLING_CALLBACK();
 *       MON4_Falling_Edge_Int_Clr();
 *     }
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON4FC_Pos, SCU_IRCON1CLR_MON4FC_Msk, 1u);
}

/** \brief Clear MON5 on rising edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON5 on rising edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON5_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 8u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON5R == (uint8)1)
 *     {
 *       MON5_RISING_CALLBACK();
 *       MON5_Rising_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_Rising_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON5RC_Pos, SCU_IRCON1CLR_MON5RC_Msk, 1u);
}

/** \brief Clear MON5 on falling edge interrupt flag.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON5 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON5_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 9u)) != 0u)
 *   {  
 *     if ((uint8)SCU->IRCON1.bit.MON5F == (uint8)1)
 *     {
 *       MON5_FALLING_CALLBACK();
 *       MON5_Falling_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_Falling_Edge_Int_Clr(void)
{
  Field_Wrt32(&SCU->IRCON1CLR.reg, (uint8)SCU_IRCON1CLR_MON5FC_Pos, SCU_IRCON1CLR_MON5FC_Msk, 1u);
}

/* MON Interrupt Enable/Disable */
/** \brief Enable MON1 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON1 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON1_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 1u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON1F == (uint8)1)
 *     {
 *       MON1_FALLING_CALLBACK();
 *       MON1_Falling_Edge_Int_Clr();
 *     } 
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_Int_En(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON1IE_Pos, SCU_MONIEN_MON1IE_Msk, 1u);
}

/** \brief Enable MON2 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON2 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON2_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 3u)) != 0u)
 *   { 	 
 *     if ((uint8)SCU->IRCON1.bit.MON2F == (uint8)1)
 *     {
 *       MON2_FALLING_CALLBACK();
 *       MON2_Falling_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_Int_En(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON2IE_Pos, SCU_MONIEN_MON2IE_Msk, 1u);
}

/** \brief Enable MON3 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON3 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON3_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 5u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON3F == (uint8)1)
 *     {
 *       MON3_FALLING_CALLBACK();
 *       MON3_Falling_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_Int_En(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON3IE_Pos, SCU_MONIEN_MON3IE_Msk, 1u);
}

/** \brief Enable MON4 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON4 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON4_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 7u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON4F == (uint8)1)
 *     {
 *       MON4_FALLING_CALLBACK();
 *       MON4_Falling_Edge_Int_Clr();
 *     }
 *   } 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_Int_En(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON4IE_Pos, SCU_MONIEN_MON4IE_Msk, 1u);
}

/** \brief Enable MON5 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON5 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON5_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 9u)) != 0u)
 *   {  
 *     if ((uint8)SCU->IRCON1.bit.MON5F == (uint8)1)
 *     {
 *       MON5_FALLING_CALLBACK();
 *       MON5_Falling_Edge_Int_Clr();
 *     }
 *   }
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_Int_En(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON5IE_Pos, SCU_MONIEN_MON5IE_Msk, 1u);
}

/** \brief Disable MON1 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON1 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON1_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 1u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON1F == (uint8)1)
 *     {
 *       MON1_FALLING_CALLBACK();
 *       MON1_Falling_Edge_Int_Clr();
 *     } 
 *   }
 *   MON1_Int_Dis();  
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_Int_Dis(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON1IE_Pos, SCU_MONIEN_MON1IE_Msk, 0u);
}

/** \brief Disable MON2 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON2 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON2_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 3u)) != 0u)
 *   { 	 
 *     if ((uint8)SCU->IRCON1.bit.MON2F == (uint8)1)
 *     {
 *       MON2_FALLING_CALLBACK();
 *       MON2_Falling_Edge_Int_Clr();
 *     }
 *   }
 *   MON2_Int_Dis(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_Int_Dis(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON2IE_Pos, SCU_MONIEN_MON2IE_Msk, 0u);
}

/** \brief Disable MON3 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON3 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON3_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 5u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON3F == (uint8)1)
 *     {
 *       MON3_FALLING_CALLBACK();
 *       MON3_Falling_Edge_Int_Clr();
 *     }
 *   }
 *   MON3_Int_Dis(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_Int_Dis(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON3IE_Pos, SCU_MONIEN_MON3IE_Msk, 0u);
}

/** \brief Disable MON4 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON4 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON4_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 7u)) != 0u)
 *   { 
 *     if ((uint8)SCU->IRCON1.bit.MON4F == (uint8)1)
 *     {
 *       MON4_FALLING_CALLBACK();
 *       MON4_Falling_Edge_Int_Clr();
 *     }
 *   } 
 *   MON4_Int_Dis();  
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_Int_Dis(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON4IE_Pos, SCU_MONIEN_MON4IE_Msk, 0u);
}

/** \brief Disable MON5 interrupt.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example treats the MON5 on falling edge interrupt.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *   MON5_Int_En(); 
 *   if ((SCU->EXICON1.reg & (1u << 9u)) != 0u)
 *   {  
 *     if ((uint8)SCU->IRCON1.bit.MON5F == (uint8)1)
 *     {
 *       MON5_FALLING_CALLBACK();
 *       MON5_Falling_Edge_Int_Clr();
 *     }
 *   }
 *   MON5_Int_Dis(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_Int_Dis(void)
{
  Field_Mod32(&SCU->MONIEN.reg, (uint8)SCU_MONIEN_MON5IE_Pos, SCU_MONIEN_MON5IE_Msk, 0u);
}

/* Register: PMU->MON_CNF1 */
/** \brief Read MON4 Status.
 *
 * \return MON4 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example reads MON4 Status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 status;
 * 
 *     status = MON4_Sts(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE uint8 MON4_Sts(void)
{
  return u1_Field_Rd32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_STS_Pos, PMU_MON_CNF1_MON4_STS_Msk);
}

/** \brief Enable PullUp for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUp for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_PullUp_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_PullUp_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_PU_Pos, PMU_MON_CNF1_MON4_PU_Msk, 1u);
}

/** \brief Disable PullUp for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUp for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_PullUp_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_PullUp_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_PU_Pos, PMU_MON_CNF1_MON4_PU_Msk, 0u);
}

/** \brief Enable PullDown for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullDown for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_PullDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_PullDown_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_PD_Pos, PMU_MON_CNF1_MON4_PD_Msk, 1u);
}

/** \brief Disable PullDown for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullDown for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_PullDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_PullDown_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_PD_Pos, PMU_MON_CNF1_MON4_PD_Msk, 0u);
}

/** \brief Enable Cycle Sense for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Cycle Sense for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_CycSense_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_CycSense_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_CYC_Pos, PMU_MON_CNF1_MON4_CYC_Msk, 1u);
}

/** \brief Disable Cycle Sense for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Cycle Sense for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_CycSense_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_CycSense_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_CYC_Pos, PMU_MON_CNF1_MON4_CYC_Msk, 0u);
}

/** \brief Enable Wake-up on Rising Edge for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Rising Edge for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_WakeOnRise_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_WakeOnRise_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_RISE_Pos, PMU_MON_CNF1_MON4_RISE_Msk, 1u);
}

/** \brief Disable Wake-up on Rising Edge for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Rising Edge for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_WakeOnRise_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_WakeOnRise_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_RISE_Pos, PMU_MON_CNF1_MON4_RISE_Msk, 0u);
}

/** \brief Enable Wake-up on Falling Edge for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Falling Edge for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_WakeOnFall_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_WakeOnFall_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_FALL_Pos, PMU_MON_CNF1_MON4_FALL_Msk, 1u);
}

/** \brief Disable Wake-up on Falling Edge for MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Falling Edge for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_WakeOnFall_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_WakeOnFall_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_FALL_Pos, PMU_MON_CNF1_MON4_FALL_Msk, 0u);
}

/** \brief Enable MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullDown for MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_En();	 
 *     MON4_PullDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_EN_Pos, PMU_MON_CNF1_MON4_EN_Msk, 1u);
}

/** \brief Disable MON4.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables MON4.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON4_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON4_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON4_EN_Pos, PMU_MON_CNF1_MON4_EN_Msk, 0u);
}


/** \brief Read MON3 Status.
 *
 * \return MON3 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example reads MON3 Status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 status;
 * 
 *     status = MON3_Sts(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE uint8 MON3_Sts(void)
{
  return u1_Field_Rd32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_STS_Pos, PMU_MON_CNF1_MON3_STS_Msk);
}

/** \brief Enable PullUp for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUp for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_PullUp_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_PullUp_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_PU_Pos, PMU_MON_CNF1_MON3_PU_Msk, 1u);
}

/** \brief Disable PullUp for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUp for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_PullUp_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_PullUp_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_PU_Pos, PMU_MON_CNF1_MON3_PU_Msk, 0u);
}

/** \brief Enable PullDown for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullDown for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_PullDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_PullDown_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_PD_Pos, PMU_MON_CNF1_MON3_PD_Msk, 1u);
}

/** \brief Disable PullDown for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullDown for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_PullDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_PullDown_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_PD_Pos, PMU_MON_CNF1_MON3_PD_Msk, 0u);
}

/** \brief Enable Cycle Sense for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Cycle Sense for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_CycSense_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_CycSense_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_CYC_Pos, PMU_MON_CNF1_MON3_CYC_Msk, 1u);
}

/** \brief Disable Cycle Sense for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Cycle Sense for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_CycSense_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_CycSense_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_CYC_Pos, PMU_MON_CNF1_MON3_CYC_Msk, 0u);
}

/** \brief Enable Wake-up on Rising Edge for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Rising Edge for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_WakeOnRise_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_WakeOnRise_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_RISE_Pos, PMU_MON_CNF1_MON3_RISE_Msk, 1u);
}

/** \brief Disable Wake-up on Rising Edge for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Rising Edge for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_WakeOnRise_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_WakeOnRise_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_RISE_Pos, PMU_MON_CNF1_MON3_RISE_Msk, 0u);
}

/** \brief Enable Wake-up on Falling Edge for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Falling Edge for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_WakeOnFall_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_WakeOnFall_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_FALL_Pos, PMU_MON_CNF1_MON3_FALL_Msk, 1u);
}

/** \brief Disable Wake-up on Falling Edge for MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Falling Edge for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_WakeOnFall_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_WakeOnFall_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_FALL_Pos, PMU_MON_CNF1_MON3_FALL_Msk, 0u);
}

/** \brief Enable MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Cycle Sense for MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_En();	 
 *     MON3_CycSense_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_EN_Pos, PMU_MON_CNF1_MON3_EN_Msk, 1u);
}

/** \brief Disable MON3.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables MON3.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON3_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON3_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON3_EN_Pos, PMU_MON_CNF1_MON3_EN_Msk, 0u);
}

/** \brief Read MON2 Status.
 *
 * \return MON2 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example reads MON2 Status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 status;
 * 
 *     status = MON2_Sts(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE uint8 MON2_Sts(void)
{
  return u1_Field_Rd32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_STS_Pos, PMU_MON_CNF1_MON2_STS_Msk);
}

/** \brief Enable PullUp for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUp for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_PullUp_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_PullUp_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_PU_Pos, PMU_MON_CNF1_MON2_PU_Msk, 1u);
}

/** \brief Disable PullUp for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUp for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_PullUp_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_PullUp_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_PU_Pos, PMU_MON_CNF1_MON2_PU_Msk, 0u);
}

/** \brief Enable PullDown for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullDown for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_PullDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_PullDown_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_PD_Pos, PMU_MON_CNF1_MON2_PD_Msk, 1u);
}

/** \brief Disable PullDown for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullDown for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_PullDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_PullDown_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_PD_Pos, PMU_MON_CNF1_MON2_PD_Msk, 0u);
}

/** \brief Enable Cycle Sense for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Cycle Sense for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_CycSense_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_CycSense_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_CYC_Pos, PMU_MON_CNF1_MON2_CYC_Msk, 1u);
}

/** \brief Disable Cycle Sense for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Cycle Sense for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_CycSense_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_CycSense_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_CYC_Pos, PMU_MON_CNF1_MON2_CYC_Msk, 0u);
}

/** \brief Enable Wake-up on Rising Edge for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Rising Edge for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_WakeOnRise_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_WakeOnRise_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_RISE_Pos, PMU_MON_CNF1_MON2_RISE_Msk, 1u);
}

/** \brief Disable Wake-up on Rising Edge for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Rising Edge for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_WakeOnRise_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_WakeOnRise_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_RISE_Pos, PMU_MON_CNF1_MON2_RISE_Msk, 0u);
}

/** \brief Enable Wake-up on Falling Edge for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Falling Edge for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_WakeOnFall_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_WakeOnFall_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_FALL_Pos, PMU_MON_CNF1_MON2_FALL_Msk, 1u);
}

/** \brief Disable Wake-up on Falling Edge for MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Falling Edge for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_WakeOnFall_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_WakeOnFall_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_FALL_Pos, PMU_MON_CNF1_MON2_FALL_Msk, 0u);
}

/** \brief Enable MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUp for MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_En();	 
 *     MON2_PullUp_En();
 * }
 * ~~~~~~~~~~~~~~~
 * \ingroup mon_api
 */
INLINE void MON2_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_EN_Pos, PMU_MON_CNF1_MON2_EN_Msk, 1u);
}

/** \brief Disable MON2.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables MON2.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON2_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON2_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON2_EN_Pos, PMU_MON_CNF1_MON2_EN_Msk, 0u);
}


/** \brief Read MON1 Status.
 *
 * \return MON1 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example reads MON1 Status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 status;
 * 
 *     status = MON1_Sts(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE uint8 MON1_Sts(void)
{
  return u1_Field_Rd32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_STS_Pos, PMU_MON_CNF1_MON1_STS_Msk);
}

/** \brief Enable PullUp for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUp for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_PullUp_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_PullUp_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_PU_Pos, PMU_MON_CNF1_MON1_PU_Msk, 1u);
}

/** \brief Disable PullUp for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUp for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_PullUp_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_PullUp_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_PU_Pos, PMU_MON_CNF1_MON1_PU_Msk, 0u);
}

/** \brief Enable PullDown for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullDown for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_PullDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_PullDown_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_PD_Pos, PMU_MON_CNF1_MON1_PD_Msk, 1u);
}

/** \brief Disable PullDown for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullDown for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_PullDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_PullDown_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_PD_Pos, PMU_MON_CNF1_MON1_PD_Msk, 0u);
}

/** \brief Enable Cycle Sense for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Cycle Sense for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_CycSense_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_CycSense_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_CYC_Pos, PMU_MON_CNF1_MON1_CYC_Msk, 1u);
}

/** \brief Disable Cycle Sense for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Cycle Sense for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_CycSense_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_CycSense_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_CYC_Pos, PMU_MON_CNF1_MON1_CYC_Msk, 0u);
}

/** \brief Enable Wake-up on Rising Edge for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Rising Edge for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_WakeOnRise_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_WakeOnRise_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_RISE_Pos, PMU_MON_CNF1_MON1_RISE_Msk, 1u);
}

/** \brief Disable Wake-up on Rising Edge for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Rising Edge for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_WakeOnRise_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_WakeOnRise_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_RISE_Pos, PMU_MON_CNF1_MON1_RISE_Msk, 0u);
}

/** \brief Enable Wake-up on Falling Edge for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Falling Edge for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_WakeOnFall_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_WakeOnFall_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_FALL_Pos, PMU_MON_CNF1_MON1_FALL_Msk, 1u);
}

/** \brief Disable Wake-up on Falling Edge for MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Falling Edge for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_WakeOnFall_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_WakeOnFall_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_FALL_Pos, PMU_MON_CNF1_MON1_FALL_Msk, 0u);
}

/** \brief Enable MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Falling Edge for MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_En();	 
 *     MON1_WakeOnFall_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_En(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_EN_Pos, PMU_MON_CNF1_MON1_EN_Msk, 1u);
}

/** \brief Disable MON1.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables MON1.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON1_Dis();	
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON1_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF1.reg, (uint8)PMU_MON_CNF1_MON1_EN_Pos, PMU_MON_CNF1_MON1_EN_Msk, 0u);
}


/* Register: PMU->MON_CNF2 */
#if (UC_FEAT_MON == 5u)
/** \brief Read MON5 Status.
 *
 * \return MON4 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example reads MON5 Status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 status;
 * 
 *     status = MON5_Sts(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE uint8 MON5_Sts(void)
{
  return u1_Field_Rd32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_STS_Pos, PMU_MON_CNF2_MON5_STS_Msk);
}

/** \brief Enable PullUp for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUp for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_PullUp_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_PullUp_En(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_PU_Pos, PMU_MON_CNF2_MON5_PU_Msk, 1u);
}

/** \brief Disable PullUp for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUp for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_PullUp_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_PullUp_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_PU_Pos, PMU_MON_CNF2_MON5_PU_Msk, 0u);
}

/** \brief Enable PullDown for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullDown for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_PullDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_PullDown_En(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_PD_Pos, PMU_MON_CNF2_MON5_PD_Msk, 1u);
}

/** \brief Disable PullDown for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullDown for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_PullDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_PullDown_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_PD_Pos, PMU_MON_CNF2_MON5_PD_Msk, 0u);
}

/** \brief Enable Cycle Sense for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Cycle Sense for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_CycSense_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_CycSense_En(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_CYC_Pos, PMU_MON_CNF2_MON5_CYC_Msk, 1u);
}

/** \brief Disable Cycle Sense for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Cycle Sense for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_CycSense_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_CycSense_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_CYC_Pos, PMU_MON_CNF2_MON5_CYC_Msk, 0u);
}

/** \brief Enable Wake-up on Rising Edge for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Rising Edge for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_WakeOnRise_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_WakeOnRise_En(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_RISE_Pos, PMU_MON_CNF2_MON5_RISE_Msk, 1u);
}

/** \brief Disable Wake-up on Rising Edge for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Rising Edge for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_WakeOnRise_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_WakeOnRise_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_RISE_Pos, PMU_MON_CNF2_MON5_RISE_Msk, 0u);
}

/** \brief Enable Wake-up on Falling Edge for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Falling Edge for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_WakeOnFall_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_WakeOnFall_En(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_FALL_Pos, PMU_MON_CNF2_MON5_FALL_Msk, 1u);
}

/** \brief Disable Wake-up on Falling Edge for MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables Wake-up on Falling Edge for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_WakeOnFall_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_WakeOnFall_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_FALL_Pos, PMU_MON_CNF2_MON5_FALL_Msk, 0u);
}

/** \brief Enable MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables Wake-up on Rising Edge for MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_En();	 
 *     MON5_WakeOnRise_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_En(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_EN_Pos, PMU_MON_CNF2_MON5_EN_Msk, 1u);
}

/** \brief Disable MON5.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables MON5.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     MON5_Dis();	
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup mon_api
 */
INLINE void MON5_Dis(void)
{
  Field_Mod32(&PMU->MON_CNF2.reg, (uint8)PMU_MON_CNF2_MON5_EN_Pos, PMU_MON_CNF2_MON5_EN_Msk, 0u);
}

#endif




#endif
