/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/**
 * \file     port.h
 *
 * \brief    Port/GPIO low level access library
 *
 * \version  V0.6.6
 * \date     01. Apr 2022
 *
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** AV           Axel Viebig                                                   **
** KC           Kay Claussen                                                  **
** CE           Christian Engel                                               **
** TS           T&S                                                           **
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
** VO           Vanessa Ongaro                                                **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2015-09-30, AV:   Initial version, ported from V0.5.1 (Proteus SDK)**
** V0.1.1: 2015-11-09, AV:   Method names: Port->PORT                         **
** V0.1.2: 2015-11-25, AV:   Corrected memory addressing in 3 inline functions**
** V0.6.0: 2017-06-19, KC:   Port prefix changed to capital letters           **
**                           API extended: Macros added                       **
** V0.6.1: 2018-11-05, CE:   Inline-Functions for PORT_P21 added              **
**                           Macros formed into inline functions              **
**                           SFR bitfield accesses replaced by functions      **
**                           (Field_Mod(), ...)                               **
**                           DoxyGen docu added                               **
** V0.6.2: 2019-03-18, TS:   All positions for Field_X functions are cast     **
**                           with uint8                                       **
** V0.6.3: 2019-03-18, JO:   Moved PORT_ChangePin, PORT_ReadPin, and          **
**                           PORT_ReadPort to c file                          **
** V0.6.4: 2021-08-16, BG:   EP-731: Updated revision history layout          **
**                           Added inline functions declarations              **
**                           Moved DoxyGen documentation for global functions **
**                           to port.c                                        **
** V0.6.5: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
** V0.6.6: 2022-04-01, VO:   EP-1091: Added initalization of registers for    **
**                           port driver strength to PORT_Init function       **
*******************************************************************************/

#ifndef PORT_H
#define PORT_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/

#include "tle984x.h"
#include "types.h"
#include "cmsis_misra.h"
#include "sfr_access.h"

/*******************************************************************************
**                          Global Macro Declarations                         **
*******************************************************************************/

/**\brief Port indices, Port P0*/
#define PORT_P0 (0U)
/**\brief Port indices, Port P1*/
#define PORT_P1 (1U)
/**\brief Port indices, Port P2*/
#define PORT_P2 (2U)

/**\brief Port actions, clear*/
#define PORT_ACTION_CLEAR  (0U)
/**\brief Port actions, set*/
#define PORT_ACTION_SET    (1U)
/**\brief Port actions, toggle*/
#define PORT_ACTION_TOGGLE (2U)
/**\brief Port actions, input*/
#define PORT_ACTION_INPUT  (3U)
/**\brief Port actions, output*/
#define PORT_ACTION_OUTPUT (4U)

/*******************************************************************************
**                        Global Function Declarations                        **
*******************************************************************************/

void PORT_Init(void);
void PORT_ChangePin(uint32 PortPin, uint32 Action);
uint32 PORT_ReadPin(uint32 PortPin);
uint32 PORT_ReadPort(uint32 Port);
void PORT_ChangePinAlt(uint32 PortPin, uint32 AltSel);
INLINE void PORT_P00_Output_Set(void);
INLINE void PORT_P00_Input_Set(void);
INLINE void PORT_P01_Output_Set(void);
INLINE void PORT_P01_Input_Set(void);
INLINE void PORT_P02_Output_Set(void);
INLINE void PORT_P02_Input_Set(void);
INLINE void PORT_P03_Output_Set(void);
INLINE void PORT_P03_Input_Set(void);
INLINE void PORT_P04_Output_Set(void);
INLINE void PORT_P04_Input_Set(void);
INLINE void PORT_P05_Output_Set(void);
INLINE void PORT_P05_Input_Set(void);
INLINE void PORT_P00_Output_High_Set(void);
INLINE void PORT_P00_Output_Low_Set(void);
INLINE void PORT_P00_Output_Toggle_Set(void);
INLINE void PORT_P01_Output_High_Set(void);
INLINE void PORT_P01_Output_Low_Set(void);
INLINE void PORT_P01_Output_Toggle_Set(void);
INLINE void PORT_P02_Output_High_Set(void);
INLINE void PORT_P02_Output_Low_Set(void);
INLINE void PORT_P02_Output_Toggle_Set(void);
INLINE void PORT_P03_Output_High_Set(void);
INLINE void PORT_P03_Output_Low_Set(void);
INLINE void PORT_P03_Output_Toggle_Set(void);
INLINE void PORT_P04_Output_High_Set(void);
INLINE void PORT_P04_Output_Low_Set(void);
INLINE void PORT_P04_Output_Toggle_Set(void);
INLINE void PORT_P05_Output_High_Set(void);
INLINE void PORT_P05_Output_Low_Set(void);
INLINE void PORT_P05_Output_Toggle_Set(void);
INLINE uint8 PORT_P00_Get(void);
INLINE uint8 PORT_P01_Get(void);
INLINE uint8 PORT_P02_Get(void);
INLINE uint8 PORT_P03_Get(void);
INLINE uint8 PORT_P04_Get(void);
INLINE uint8 PORT_P05_Get(void);
INLINE void PORT_P00_OpenDrain_En(void);
INLINE void PORT_P00_OpenDrain_Dis(void);
INLINE void PORT_P01_OpenDrain_En(void);
INLINE void PORT_P01_OpenDrain_Dis(void);
INLINE void PORT_P02_OpenDrain_En(void);
INLINE void PORT_P02_OpenDrain_Dis(void);
INLINE void PORT_P03_OpenDrain_En(void);
INLINE void PORT_P03_OpenDrain_Dis(void);
INLINE void PORT_P04_OpenDrain_En(void);
INLINE void PORT_P04_OpenDrain_Dis(void);
INLINE void PORT_P05_OpenDrain_En(void);
INLINE void PORT_P05_OpenDrain_Dis(void);
INLINE void PORT_P00_PullUpDown_En(void);
INLINE void PORT_P00_PullUpDown_Dis(void);
INLINE void PORT_P01_PullUpDown_En(void);
INLINE void PORT_P01_PullUpDown_Dis(void);
INLINE void PORT_P02_PullUpDown_En(void);
INLINE void PORT_P02_PullUpDown_Dis(void);
INLINE void PORT_P03_PullUpDown_En(void);
INLINE void PORT_P03_PullUpDown_Dis(void);
INLINE void PORT_P04_PullUpDown_En(void);
INLINE void PORT_P04_PullUpDown_Dis(void);
INLINE void PORT_P05_PullUpDown_En(void);
INLINE void PORT_P05_PullUpDown_Dis(void);
INLINE void PORT_P00_PullUp_Set(void);
INLINE void PORT_P00_PullDown_Set(void);
INLINE void PORT_P01_PullUp_Set(void);
INLINE void PORT_P01_PullDown_Set(void);
INLINE void PORT_P02_PullUp_Set(void);
INLINE void PORT_P02_PullDown_Set(void);
INLINE void PORT_P03_PullUp_Set(void);
INLINE void PORT_P03_PullDown_Set(void);
INLINE void PORT_P04_PullUp_Set(void);
INLINE void PORT_P04_PullDown_Set(void);
INLINE void PORT_P05_PullUp_Set(void);
INLINE void PORT_P05_PullDown_Set(void);
INLINE void PORT_P10_Output_Set(void);
INLINE void PORT_P10_Input_Set(void);
INLINE void PORT_P11_Output_Set(void);
INLINE void PORT_P11_Input_Set(void);
INLINE void PORT_P12_Output_Set(void);
INLINE void PORT_P12_Input_Set(void);
INLINE void PORT_P14_Output_Set(void);
INLINE void PORT_P14_Input_Set(void);
INLINE void PORT_P10_Output_High_Set(void);
INLINE void PORT_P10_Output_Low_Set(void);
INLINE void PORT_P10_Output_Toggle_Set(void);
INLINE void PORT_P11_Output_High_Set(void);
INLINE void PORT_P11_Output_Low_Set(void);
INLINE void PORT_P11_Output_Toggle_Set(void);
INLINE void PORT_P12_Output_High_Set(void);
INLINE void PORT_P12_Output_Low_Set(void);
INLINE void PORT_P12_Output_Toggle_Set(void);
INLINE void PORT_P14_Output_High_Set(void);
INLINE void PORT_P14_Output_Low_Set(void);
INLINE void PORT_P14_Output_Toggle_Set(void);
INLINE uint8 PORT_P10_Get(void);
INLINE uint8 PORT_P11_Get(void);
INLINE uint8 PORT_P12_Get(void);
INLINE uint8 PORT_P14_Get(void);
INLINE void PORT_P10_OpenDrain_En(void);
INLINE void PORT_P10_OpenDrain_Dis(void);
INLINE void PORT_P11_OpenDrain_En(void);
INLINE void PORT_P11_OpenDrain_Dis(void);
INLINE void PORT_P12_OpenDrain_En(void);
INLINE void PORT_P12_OpenDrain_Dis(void);
INLINE void PORT_P14_OpenDrain_En(void);
INLINE void PORT_P14_OpenDrain_Dis(void);
INLINE void PORT_P10_PullUpDown_En(void);
INLINE void PORT_P10_PullUpDown_Dis(void);
INLINE void PORT_P11_PullUpDown_En(void);
INLINE void PORT_P11_PullUpDown_Dis(void);
INLINE void PORT_P12_PullUpDown_En(void);
INLINE void PORT_P12_PullUpDown_Dis(void);
INLINE void PORT_P14_PullUpDown_En(void);
INLINE void PORT_P14_PullUpDown_Dis(void);
INLINE void PORT_P10_PullUp_Set(void);
INLINE void PORT_P10_PullDown_Set(void);
INLINE void PORT_P11_PullUp_Set(void);
INLINE void PORT_P11_PullDown_Set(void);
INLINE void PORT_P12_PullUp_Set(void);
INLINE void PORT_P12_PullDown_Set(void);
INLINE void PORT_P14_PullUp_Set(void);
INLINE void PORT_P14_PullDown_Set(void);
INLINE void PORT_P20_Dis(void);
INLINE void PORT_P20_Input_Set(void);
INLINE void PORT_P21_Dis(void);
INLINE void PORT_P21_Input_Set(void);
INLINE void PORT_P22_Dis(void);
INLINE void PORT_P22_Input_Set(void);
INLINE void PORT_P23_Dis(void);
INLINE void PORT_P23_Input_Set(void);
INLINE void PORT_P24_Dis(void);
INLINE void PORT_P24_Input_Set(void);
INLINE void PORT_P25_Dis(void);
INLINE void PORT_P25_Input_Set(void);
INLINE void PORT_P26_Dis(void);
INLINE void PORT_P26_Input_Set(void);
INLINE void PORT_P27_Dis(void);
INLINE void PORT_P27_Input_Set(void);
INLINE uint8 PORT_P20_Get(void);
INLINE uint8 PORT_P21_Get(void);
INLINE uint8 PORT_P22_Get(void);
INLINE uint8 PORT_P23_Get(void);
INLINE uint8 PORT_P24_Get(void);
INLINE uint8 PORT_P25_Get(void);
INLINE uint8 PORT_P26_Get(void);
INLINE uint8 PORT_P27_Get(void);
INLINE void PORT_P20_PullUpDown_En(void);
INLINE void PORT_P20_PullUpDown_Dis(void);
INLINE void PORT_P21_PullUpDown_En(void);
INLINE void PORT_P21_PullUpDown_Dis(void);
INLINE void PORT_P22_PullUpDown_En(void);
INLINE void PORT_P22_PullUpDown_Dis(void);
INLINE void PORT_P23_PullUpDown_En(void);
INLINE void PORT_P23_PullUpDown_Dis(void);
INLINE void PORT_P24_PullUpDown_En(void);
INLINE void PORT_P24_PullUpDown_Dis(void);
INLINE void PORT_P25_PullUpDown_En(void);
INLINE void PORT_P25_PullUpDown_Dis(void);
INLINE void PORT_P26_PullUpDown_En(void);
INLINE void PORT_P26_PullUpDown_Dis(void);
INLINE void PORT_P27_PullUpDown_En(void);
INLINE void PORT_P27_PullUpDown_Dis(void);
INLINE void PORT_P20_PullUp_Set(void);
INLINE void PORT_P20_PullDown_Set(void);
INLINE void PORT_P21_PullUp_Set(void);
INLINE void PORT_P21_PullDown_Set(void);
INLINE void PORT_P22_PullUp_Set(void);
INLINE void PORT_P22_PullDown_Set(void);
INLINE void PORT_P23_PullUp_Set(void);
INLINE void PORT_P23_PullDown_Set(void);
INLINE void PORT_P24_PullUp_Set(void);
INLINE void PORT_P24_PullDown_Set(void);
INLINE void PORT_P25_PullUp_Set(void);
INLINE void PORT_P25_PullDown_Set(void);
INLINE void PORT_P26_PullUp_Set(void);
INLINE void PORT_P26_PullDown_Set(void);
INLINE void PORT_P27_PullUp_Set(void);
INLINE void PORT_P27_PullDown_Set(void);

/*******************************************************************************
**                     Global Inline Function Definitions                     **
*******************************************************************************/

/** \brief Set Port P00 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_Output_Set();
 *     PORT_P00_Output_High_Set();
 *	   PORT_P00_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_Output_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP0_Pos, PORT_P0_DIR_PP0_Msk, 1u);
}

/** \brief Set Port P00 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P00_Input_Set();
 *     sts = PORT_P00_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_Input_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP0_Pos, PORT_P0_DIR_PP0_Msk, 0u);
}

/** \brief Set Port P01 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_Output_Set();
 *     PORT_P01_Output_High_Set();
 *	   PORT_P01_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_Output_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP1_Pos, PORT_P0_DIR_PP1_Msk, 1u);
}

/** \brief Set Port P01 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P01_Input_Set();
 *     sts = PORT_P01_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_Input_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP1_Pos, PORT_P0_DIR_PP1_Msk, 0u);
}

/** \brief Set Port P02 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_Output_Set();
 *     PORT_P02_Output_High_Set();
 *	   PORT_P02_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_Output_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP2_Pos, PORT_P0_DIR_PP2_Msk, 1u);
}

/** \brief Set Port P02 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P02_Input_Set();
 *     sts = PORT_P02_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_Input_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP2_Pos, PORT_P0_DIR_PP2_Msk, 0u);
}

/** \brief Set Port P03 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_Output_Set();
 *     PORT_P03_Output_High_Set();
 *	   PORT_P03_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_Output_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP3_Pos, PORT_P0_DIR_PP3_Msk, 1u);
}

/** \brief Set Port P03 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P03_Input_Set();
 *     sts = PORT_P03_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_Input_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP3_Pos, PORT_P0_DIR_PP3_Msk, 0u);
}

/** \brief Set Port P04 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_Output_Set();
 *     PORT_P04_Output_High_Set();
 *	   PORT_P04_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_Output_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP4_Pos, PORT_P0_DIR_PP4_Msk, 1u);
}

/** \brief Set Port P04 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P04_Input_Set();
 *     sts = PORT_P04_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_Input_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP4_Pos, PORT_P0_DIR_PP4_Msk, 0u);
}

/** \brief Set Port P05 to Output.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_Output_Set();
 *     PORT_P05_Output_High_Set();
 *	   PORT_P05_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_Output_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP5_Pos, PORT_P0_DIR_PP5_Msk, 1u);
}

/** \brief Set Port P05 to Input.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P05_Input_Set();
 *     sts = PORT_P05_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_Input_Set(void)
{
  Field_Mod32(&PORT->P0_DIR.reg, (uint8)PORT_P0_DIR_PP5_Pos, PORT_P0_DIR_PP5_Msk, 0u);
}

/** \brief Set Port P00 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_Output_Set();
 *     PORT_P00_Output_High_Set();
 *	   PORT_P00_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_Output_High_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP0_Pos, PORT_P0_DATA_PP0_Msk, 1u);
}

/** \brief Set Port P00 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_Output_Set();
 *     PORT_P00_Output_Low_Set();
 *	   PORT_P00_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP0_Pos, PORT_P0_DATA_PP0_Msk, 0u);
}

/** \brief Set Port P00 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_Output_Set();
 *     PORT_P00_Output_Toggle_Set();
 *	   PORT_P00_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP0_Msk);
}

/** \brief Set Port P01 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_Output_Set();
 *     PORT_P01_Output_High_Set();
 *	   PORT_P01_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_Output_High_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP1_Pos, PORT_P0_DATA_PP1_Msk, 1u);
}

/** \brief Set Port P01 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_Output_Set();
 *     PORT_P01_Output_Low_Set();
 *	   PORT_P01_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP1_Pos, PORT_P0_DATA_PP1_Msk, 0u);
}

/** \brief Set Port P01 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_Output_Set();
 *     PORT_P01_Output_Toggle_Set();
 *	   PORT_P01_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP1_Msk);
}

/** \brief Set Port P02 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_Output_Set();
 *     PORT_P02_Output_High_Set();
 *	   PORT_P02_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_Output_High_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP2_Pos, PORT_P0_DATA_PP2_Msk, 1u);
}

/** \brief Set Port P02 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_Output_Set();
 *     PORT_P02_Output_Low_Set();
 *	   PORT_P02_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP2_Pos, PORT_P0_DATA_PP2_Msk, 0u);
}

/** \brief Set Port P02 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_Output_Set();
 *     PORT_P02_Output_Toggle_Set();
 *	   PORT_P02_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP2_Msk);
}

/** \brief Set Port P03 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_Output_Set();
 *     PORT_P03_Output_High_Set();
 *	   PORT_P03_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_Output_High_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP3_Pos, PORT_P0_DATA_PP3_Msk, 1u);
}

/** \brief Set Port P03 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_Output_Set();
 *     PORT_P03_Output_Low_Set();
 *	   PORT_P03_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP3_Pos, PORT_P0_DATA_PP3_Msk, 0u);
}

/** \brief Set Port P03 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_Output_Set();
 *     PORT_P03_Output_Toggle_Set();
 *	   PORT_P03_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP3_Msk);
}

/** \brief Set Port P04 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_Output_Set();
 *     PORT_P04_Output_High_Set();
 *	   PORT_P04_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_Output_High_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP4_Pos, PORT_P0_DATA_PP4_Msk, 1u);
}

/** \brief Set Port P04 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_Output_Set();
 *     PORT_P04_Output_Low_Set();
 *	   PORT_P04_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP4_Pos, PORT_P0_DATA_PP4_Msk, 0u);
}

/** \brief Set Port P04 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_Output_Set();
 *     PORT_P04_Output_Toggle_Set();
 *	   PORT_P04_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP4_Msk);
}

/** \brief Set Port P05 to High Status.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_Output_Set();
 *     PORT_P05_Output_High_Set();
 *	   PORT_P05_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_Output_High_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP5_Pos, PORT_P0_DATA_PP5_Msk, 1u);
}

/** \brief Set Port P05 to Low Status.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_Output_Set();
 *     PORT_P05_Output_Low_Set();
 *	   PORT_P05_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP5_Pos, PORT_P0_DATA_PP5_Msk, 0u);
}

/** \brief Set Port P05 to Toggle Status.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_Output_Set();
 *     PORT_P05_Output_Toggle_Set();
 *	   PORT_P05_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP5_Msk);
}

/** \brief Read Port P00 Status.
 *
 * \return P00 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 * 
 *     PORT_P00_Input_Set();
 *     sts = PORT_P00_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P00_Get(void)
{
  return u1_Field_Rd32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP0_Pos, PORT_P0_DATA_PP0_Msk);
}

/** \brief Read Port P01 Status.
 *
 * \return P01 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *  
 *     PORT_P01_Input_Set();
 *     sts = PORT_P01_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P01_Get(void)
{
  return u1_Field_Rd32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP1_Pos, PORT_P0_DATA_PP1_Msk);
}

/** \brief Read Port P02 Status.
 *
 * \return P02 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P02_Input_Set();
 *     sts = PORT_P02_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P02_Get(void)
{
  return u1_Field_Rd32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP2_Pos, PORT_P0_DATA_PP2_Msk);
}

/** \brief Read Port P03 Status.
 *
 * \return P03 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P03_Input_Set();
 *     sts = PORT_P03_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P03_Get(void)
{
  return u1_Field_Rd32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP3_Pos, PORT_P0_DATA_PP3_Msk);
}

/** \brief Read Port P04 Status.
 *
 * \return P04 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P04_Input_Set();
 *     sts = PORT_P04_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P04_Get(void)
{
  return u1_Field_Rd32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP4_Pos, PORT_P0_DATA_PP4_Msk);
}

/** \brief Read Port P05 Status.
 *
 * \return P05 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P05_Input_Set();
 *     sts = PORT_P05_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P05_Get(void)
{
  return u1_Field_Rd32(&PORT->P0_DATA.reg, (uint8)PORT_P0_DATA_PP5_Pos, PORT_P0_DATA_PP5_Msk);
}


/** \brief Enable Output OpenDrain for Port P00.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_Output_Set();
 *     PORT_P00_Output_Low_Set();
 *	   PORT_P00_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP0_Pos, PORT_P0_OD_PP0_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P00.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P00 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_Output_Set();
 *     PORT_P00_Output_Low_Set();
 *	   PORT_P00_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP0_Pos, PORT_P0_OD_PP0_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P01.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_Output_Set();
 *     PORT_P01_Output_Low_Set();
 *	   PORT_P01_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP1_Pos, PORT_P0_OD_PP1_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P01.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P01 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_Output_Set();
 *     PORT_P01_Output_Low_Set();
 *	   PORT_P01_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP1_Pos, PORT_P0_OD_PP1_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P02.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_Output_Set();
 *     PORT_P02_Output_Low_Set();
 *	   PORT_P02_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP2_Pos, PORT_P0_OD_PP2_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P02.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P02 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_Output_Set();
 *     PORT_P02_Output_Low_Set();
 *	   PORT_P02_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP2_Pos, PORT_P0_OD_PP2_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P03.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_Output_Set();
 *     PORT_P03_Output_Low_Set();
 *	   PORT_P03_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP3_Pos, PORT_P0_OD_PP3_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P03.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P03 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_Output_Set();
 *     PORT_P03_Output_Low_Set();
 *	   PORT_P03_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP3_Pos, PORT_P0_OD_PP3_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P04.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_Output_Set();
 *     PORT_P04_Output_Low_Set();
 *	   PORT_P04_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP4_Pos, PORT_P0_OD_PP4_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P04.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P04 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_Output_Set();
 *     PORT_P04_Output_Low_Set();
 *	   PORT_P04_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP4_Pos, PORT_P0_OD_PP4_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P05.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_Output_Set();
 *     PORT_P05_Output_Low_Set();
 *	   PORT_P05_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP5_Pos, PORT_P0_OD_PP5_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P05.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P05 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_Output_Set();
 *     PORT_P05_Output_Low_Set();
 *	   PORT_P05_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P0_OD.reg, (uint8)PORT_P0_OD_PP5_Pos, PORT_P0_OD_PP5_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P00.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P00.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP0_Pos, PORT_P0_PUDEN_PP0_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P00.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P00.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP0_Pos, PORT_P0_PUDEN_PP0_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P01.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P01.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP1_Pos, PORT_P0_PUDEN_PP1_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P01.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P01.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP1_Pos, PORT_P0_PUDEN_PP1_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P02.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P02.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP2_Pos, PORT_P0_PUDEN_PP2_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P02.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P02.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP2_Pos, PORT_P0_PUDEN_PP2_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P03.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P03.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP3_Pos, PORT_P0_PUDEN_PP3_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P03.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P03.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP3_Pos, PORT_P0_PUDEN_PP3_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P04.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P04.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP4_Pos, PORT_P0_PUDEN_PP4_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P04.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P04.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP4_Pos, PORT_P0_PUDEN_PP4_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P05.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P05.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP5_Pos, PORT_P0_PUDEN_PP5_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P05.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P05.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P0_PUDEN.reg, (uint8)PORT_P0_PUDEN_PP5_Pos, PORT_P0_PUDEN_PP5_Msk, 0u);
}

/** \brief Set PullUp for Port P00.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P00.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_PullUpDown_En();
 *     PORT_P00_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_PullUp_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP0_Pos, PORT_P0_PUDSEL_PP0_Msk, 1u);
}

/** \brief Set PullDown for Port P00.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P00.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P00_PullUpDown_En();
 *     PORT_P00_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P00_PullDown_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP0_Pos, PORT_P0_PUDSEL_PP0_Msk, 0u);
}

/** \brief Set PullUp for Port P01.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P01.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_PullUpDown_En();
 *     PORT_P01_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_PullUp_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP1_Pos, PORT_P0_PUDSEL_PP1_Msk, 1u);
}

/** \brief Set PullDown for Port P01.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P01.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P01_PullUpDown_En();
 *     PORT_P01_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P01_PullDown_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP1_Pos, PORT_P0_PUDSEL_PP1_Msk, 0u);
}

/** \brief Set PullUp for Port P02.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P02.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_PullUpDown_En();
 *     PORT_P02_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_PullUp_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP2_Pos, PORT_P0_PUDSEL_PP2_Msk, 1u);
}

/** \brief Set PullDown for Port P02.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P02.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P02_PullUpDown_En();
 *     PORT_P02_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P02_PullDown_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP2_Pos, PORT_P0_PUDSEL_PP2_Msk, 0u);
}

/** \brief Set PullUp for Port P03.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P03.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_PullUpDown_En();
 *     PORT_P03_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_PullUp_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP3_Pos, PORT_P0_PUDSEL_PP3_Msk, 1u);
}

/** \brief Set PullDown for Port P03.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P03.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P03_PullUpDown_En();
 *     PORT_P03_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P03_PullDown_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP3_Pos, PORT_P0_PUDSEL_PP3_Msk, 0u);
}

/** \brief Set PullUp for Port P04.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P04.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_PullUpDown_En();
 *     PORT_P04_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_PullUp_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP4_Pos, PORT_P0_PUDSEL_PP4_Msk, 1u);
}

/** \brief Set PullDown for Port P04.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P04.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P04_PullUpDown_En();
 *     PORT_P04_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P04_PullDown_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP4_Pos, PORT_P0_PUDSEL_PP4_Msk, 0u);
}

/** \brief Set PullUp for Port P05.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P05.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_PullUpDown_En();
 *     PORT_P05_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_PullUp_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP5_Pos, PORT_P0_PUDSEL_PP5_Msk, 1u);
}

/** \brief Set PullDown for Port P05.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P05.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P05_PullUpDown_En();
 *     PORT_P05_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P05_PullDown_Set(void)
{
  Field_Mod32(&PORT->P0_PUDSEL.reg, (uint8)PORT_P0_PUDSEL_PP5_Pos, PORT_P0_PUDSEL_PP5_Msk, 0u);
}


/* Port1 */
/** \brief Set Port P10 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_Output_Set();
 *     PORT_P10_Output_High_Set();
 *	   PORT_P10_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_Output_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP0_Pos, PORT_P1_DIR_PP0_Msk, 1u);
}

/** \brief Set Port P10 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P10_Input_Set();
 *     sts = PORT_P10_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_Input_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP0_Pos, PORT_P1_DIR_PP0_Msk, 0u);
}

/** \brief Set Port P11 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_Output_Set();
 *     PORT_P11_Output_High_Set();
 *	   PORT_P11_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_Output_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP1_Pos, PORT_P1_DIR_PP1_Msk, 1u);
}

/** \brief Set Port P11 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P11_Input_Set();
 *     sts = PORT_P11_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_Input_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP1_Pos, PORT_P1_DIR_PP1_Msk, 0u);
}

/** \brief Set Port P12 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_Output_Set();
 *     PORT_P12_Output_High_Set();
 *	   PORT_P12_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_Output_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP2_Pos, PORT_P1_DIR_PP2_Msk, 1u);
}

/** \brief Set Port P12 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P12_Input_Set();
 *     sts = PORT_P12_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_Input_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP2_Pos, PORT_P1_DIR_PP2_Msk, 0u);
}

/** \brief Set Port P14 to Output.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_Output_Set();
 *     PORT_P14_Output_High_Set();
 *	   PORT_P14_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_Output_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP4_Pos, PORT_P1_DIR_PP4_Msk, 1u);
}

/** \brief Set Port P14 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P14_Input_Set();
 *     sts = PORT_P14_Get(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_Input_Set(void)
{
  Field_Mod32(&PORT->P1_DIR.reg, (uint8)PORT_P1_DIR_PP4_Pos, PORT_P1_DIR_PP4_Msk, 0u);
}

/** \brief Set Port P10 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_Output_Set();
 *     PORT_P10_Output_High_Set();
 *	   PORT_P10_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_Output_High_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP0_Pos, PORT_P1_DATA_PP0_Msk, 1u);
}

/** \brief Set Port P10 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_Output_Set();
 *     PORT_P10_Output_Low_Set();
 *	   PORT_P10_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP0_Pos, PORT_P1_DATA_PP0_Msk, 0u);
}

/** \brief Set Port P10 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_Output_Set();
 *     PORT_P10_Output_Toggle_Set();
 *	   PORT_P10_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP0_Msk);
}

/** \brief Set Port P11 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_Output_Set();
 *     PORT_P11_Output_High_Set();
 *	   PORT_P11_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_Output_High_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP1_Pos, PORT_P1_DATA_PP1_Msk, 1u);
}

/** \brief Set Port P11 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_Output_Set();
 *     PORT_P11_Output_Low_Set();
 *	   PORT_P11_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP1_Pos, PORT_P1_DATA_PP1_Msk, 0u);
}

/** \brief Set Port P11 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_Output_Set();
 *     PORT_P11_Output_Toggle_Set();
 *	   PORT_P11_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP1_Msk);
}

/** \brief Set Port P12 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_Output_Set();
 *     PORT_P12_Output_High_Set();
 *	   PORT_P12_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_Output_High_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP2_Pos, PORT_P1_DATA_PP2_Msk, 1u);
}

/** \brief Set Port P12 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_Output_Set();
 *     PORT_P12_Output_Low_Set();
 *	   PORT_P12_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP2_Pos, PORT_P1_DATA_PP2_Msk, 0u);
}

/** \brief Set Port P12 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_Output_Set();
 *     PORT_P12_Output_Toggle_Set();
 *	   PORT_P12_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP2_Msk);
}

/** \brief Set Port P14 to High Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as output, High and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_Output_Set();
 *     PORT_P14_Output_High_Set();
 *	   PORT_P14_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_Output_High_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP4_Pos, PORT_P1_DATA_PP4_Msk, 1u);
}

/** \brief Set Port P14 to Low Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_Output_Set();
 *     PORT_P14_Output_Low_Set();
 *	   PORT_P14_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_Output_Low_Set(void)
{
  Field_Mod32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP4_Pos, PORT_P1_DATA_PP4_Msk, 0u);
}

/** \brief Set Port P14 to Toggle Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as output, Toggle and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_Output_Set();
 *     PORT_P14_Output_Toggle_Set();
 *	   PORT_P14_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_Output_Toggle_Set(void)
{
  Field_Inv32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP4_Msk);
}

/** \brief Read Port P10 Status.
 *
 * \return P10 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P10_Input_Set();
 *     sts = PORT_P10_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P10_Get(void)
{
  return u1_Field_Rd32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP0_Pos, PORT_P1_DATA_PP0_Msk);
}

/** \brief Read Port P11 Status.
 *
 * \return P11 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P11_Input_Set();
 *     sts = PORT_P11_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P11_Get(void)
{
  return u1_Field_Rd32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP1_Pos, PORT_P1_DATA_PP1_Msk);
}

/** \brief Read Port P12 Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P12_Input_Set();
 *     sts = PORT_P12_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P12_Get(void)
{
  return u1_Field_Rd32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP2_Pos, PORT_P1_DATA_PP2_Msk);
}

/** \brief Read Port P14 Status.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P14_Input_Set();
 *     sts = PORT_P14_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P14_Get(void)
{
  return u1_Field_Rd32(&PORT->P1_DATA.reg, (uint8)PORT_P1_DATA_PP4_Pos, PORT_P1_DATA_PP4_Msk);
}

/** \brief Enable Output OpenDrain for Port P10.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_Output_Set();
 *     PORT_P10_Output_Low_Set();
 *	   PORT_P10_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP0_Pos, PORT_P1_OD_PP0_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P10.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P10 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_Output_Set();
 *     PORT_P10_Output_Low_Set();
 *	   PORT_P10_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP0_Pos, PORT_P1_OD_PP0_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P11.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_Output_Set();
 *     PORT_P11_Output_Low_Set();
 *	   PORT_P11_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP1_Pos, PORT_P1_OD_PP1_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P11.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P11 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_Output_Set();
 *     PORT_P11_Output_Low_Set();
 *	   PORT_P11_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP1_Pos, PORT_P1_OD_PP1_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P12.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_Output_Set();
 *     PORT_P12_Output_Low_Set();
 *	   PORT_P12_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP2_Pos, PORT_P1_OD_PP2_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P12.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P12 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_Output_Set();
 *     PORT_P12_Output_Low_Set();
 *	   PORT_P12_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP2_Pos, PORT_P1_OD_PP2_Msk, 0u);
}

/** \brief Enable Output OpenDrain for Port P14.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as output, Low and Open-Drain.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_Output_Set();
 *     PORT_P14_Output_Low_Set();
 *	   PORT_P14_OpenDrain_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_OpenDrain_En(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP4_Pos, PORT_P1_OD_PP4_Msk, 1u);
}

/** \brief Disable Output OpenDrain for Port P14.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P14 as output, Low and Normal Mode.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_Output_Set();
 *     PORT_P14_Output_Low_Set();
 *	   PORT_P14_OpenDrain_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_OpenDrain_Dis(void)
{
  Field_Mod32(&PORT->P1_OD.reg, (uint8)PORT_P1_OD_PP4_Pos, PORT_P1_OD_PP4_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P10.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P10.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP0_Pos, PORT_P1_PUDEN_PP0_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P10.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P10.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP0_Pos, PORT_P1_PUDEN_PP0_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P11.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P11.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP1_Pos, PORT_P1_PUDEN_PP1_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P11.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P11.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP1_Pos, PORT_P1_PUDEN_PP1_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P12.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P12.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP2_Pos, PORT_P1_PUDEN_PP2_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P12.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P12.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP2_Pos, PORT_P1_PUDEN_PP2_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P14.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P14.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP4_Pos, PORT_P1_PUDEN_PP4_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P14.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P14.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P1_PUDEN.reg, (uint8)PORT_P1_PUDEN_PP4_Pos, PORT_P1_PUDEN_PP4_Msk, 0u);
}

/** \brief Set PullUp for Port P10.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P10.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_PullUpDown_En();
 *     PORT_P10_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_PullUp_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP0_Pos, PORT_P1_PUDSEL_PP0_Msk, 1u);
}

/** \brief Set PullDown for Port P10.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P10.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P10_PullUpDown_En();
 *     PORT_P10_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P10_PullDown_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP0_Pos, PORT_P1_PUDSEL_PP0_Msk, 0u);
}

/** \brief Set PullUp for Port P11.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P11.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_PullUpDown_En();
 *     PORT_P11_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_PullUp_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP1_Pos, PORT_P1_PUDSEL_PP1_Msk, 1u);
}

/** \brief Set PullDown for Port P11.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P11.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P11_PullUpDown_En();
 *     PORT_P11_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P11_PullDown_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP1_Pos, PORT_P1_PUDSEL_PP1_Msk, 0u);
}

/** \brief Set PullUp for Port P12.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P12.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_PullUpDown_En();
 *     PORT_P12_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_PullUp_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP2_Pos, PORT_P1_PUDSEL_PP2_Msk, 1u);
}

/** \brief Set PullDown for Port P12.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P12.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_PullUpDown_En();
 *     PORT_P12_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P12_PullDown_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP2_Pos, PORT_P1_PUDSEL_PP2_Msk, 0u);
}

/** \brief Set PullUp for Port P14.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P14.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_PullUpDown_En();
 *     PORT_P14_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_PullUp_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP4_Pos, PORT_P1_PUDSEL_PP4_Msk, 1u);
}

/** \brief Set PullDown for Port P14.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P14.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P14_PullUpDown_En();
 *     PORT_P14_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P14_PullDown_Set(void)
{
  Field_Mod32(&PORT->P1_PUDSEL.reg, (uint8)PORT_P1_PUDSEL_PP4_Pos, PORT_P1_PUDSEL_PP4_Msk, 0u);
}

/* Port2 */
/** \brief Set Port P20 to Disable.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P20 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P20_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P20_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP0_Pos, PORT_P2_DIR_PP0_Msk, 1u);
}

/** \brief Set Port P20 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P20 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P20_Input_Set();
 *     sts = PORT_P20_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P20_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP0_Pos, PORT_P2_DIR_PP0_Msk, 0u);
}

/** \brief Set Port P21 to Disable.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P21 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P21_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P21_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP1_Pos, PORT_P2_DIR_PP1_Msk, 1u);
}

/** \brief Set Port P21 to Input.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P21 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P21_Input_Set();
 *     sts = PORT_P21_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P21_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP1_Pos, PORT_P2_DIR_PP1_Msk, 0u);
}
/** \brief Set Port P22 to Disable.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P22 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P22_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P22_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP2_Pos, PORT_P2_DIR_PP2_Msk, 1u);
}

/** \brief Set Port P22 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P22 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P22_Input_Set();
 *     sts = PORT_P22_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P22_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP2_Pos, PORT_P2_DIR_PP2_Msk, 0u);
}

/** \brief Set Port P23 to Disable.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P23 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P23_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P23_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP3_Pos, PORT_P2_DIR_PP3_Msk, 1u);
}

/** \brief Set Port P23 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P23 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P23_Input_Set();
 *     sts = PORT_P23_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P23_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP3_Pos, PORT_P2_DIR_PP3_Msk, 0u);
}

/** \brief Set Port P24 to Disable.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P24 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P24_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P24_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP4_Pos, PORT_P2_DIR_PP4_Msk, 1u);
}

/** \brief Set Port P24 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P24 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P24_Input_Set();
 *     sts = PORT_P24_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P24_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP4_Pos, PORT_P2_DIR_PP4_Msk, 0u);
}

/** \brief Set Port P25 to Disable.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P25 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P25_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P25_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP5_Pos, PORT_P2_DIR_PP5_Msk, 1u);
}

/** \brief Set Port P25 to Input.
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P25 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P25_Input_Set();
 *     sts = PORT_P25_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P25_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP5_Pos, PORT_P2_DIR_PP5_Msk, 0u);
}

/** \brief Set Port P26 to Disable.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P26 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P26_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P26_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP6_Pos, PORT_P2_DIR_PP6_Msk, 1u);
}

/** \brief Set Port P26 to Input.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P26 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P26_Input_Set();
 *     sts = PORT_P26_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P26_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP6_Pos, PORT_P2_DIR_PP6_Msk, 0u);
}

/** \brief Set Port P27 to Disable.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets P27 to disable.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P27_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P27_Dis(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP7_Pos, PORT_P2_DIR_PP7_Msk, 1u);
}

/** \brief Set Port P27 to Input.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P27 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P27_Input_Set();
 *     sts = PORT_P27_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P27_Input_Set(void)
{
  Field_Mod32(&PORT->P2_DIR.reg, (uint8)PORT_P2_DIR_PP7_Pos, PORT_P2_DIR_PP7_Msk, 0u);
}

/* Port2 Input */
/** \brief Read Port P20 Status.
 *
 * \return P20 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P20 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P20_Input_Set();
 *     sts = PORT_P20_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P20_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP0_Pos, PORT_P2_DATA_PP0_Msk);
}

/** \brief Read Port P21 Status.
 *
 * \return P21 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P21 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P21_Input_Set();
 *     sts = PORT_P21_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P21_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP1_Pos, PORT_P2_DATA_PP1_Msk);
}

/** \brief Read Port P22 Status.
 *
 * \return P22 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P22 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P22_Input_Set();
 *     sts = PORT_P22_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P22_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP2_Pos, PORT_P2_DATA_PP2_Msk);
}

/** \brief Read Port P23 Status.
 *
 * \return P23 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P23 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P23_Input_Set();
 *     sts = PORT_P23_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P23_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP3_Pos, PORT_P2_DATA_PP3_Msk);
}

/** \brief Read Port P24 Status.
 *
 * \return P24 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P24 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P24_Input_Set();
 *     sts = PORT_P24_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P24_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP4_Pos, PORT_P2_DATA_PP4_Msk);
}

/** \brief Read Port P25 Status.
 *
 * \return P25 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P25 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P25_Input_Set();
 *     sts = PORT_P25_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P25_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP5_Pos, PORT_P2_DATA_PP5_Msk);
}

/** \brief Read Port P26 Status.
 *
 * \return P26 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P26 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P26_Input_Set();
 *     sts = PORT_P26_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P26_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP6_Pos, PORT_P2_DATA_PP6_Msk);
}

/** \brief Read Port P27 Status.
 *
 * \return P27 Status
 *
 * \brief <b>Example</b><br>
 * \brief This example configures P27 as input and reads the status.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint8 sts;
 *
 *     PORT_P27_Input_Set();
 *     sts = PORT_P27_Get();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE uint8 PORT_P27_Get(void)
{
  return u1_Field_Rd32(&PORT->P2_DATA.reg, (uint8)PORT_P2_DATA_PP7_Pos, PORT_P2_DATA_PP7_Msk);
}

/** \brief Enable PullUpDown for Port P20.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P20.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P20_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P20_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP0_Pos, PORT_P2_PUDEN_PP0_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P20.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P20.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P20_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P20_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP0_Pos, PORT_P2_PUDEN_PP0_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P21.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P21.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P21_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P21_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP1_Pos, PORT_P2_PUDEN_PP1_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P21.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P21.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P21_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P21_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP1_Pos, PORT_P2_PUDEN_PP1_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P22.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P22.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P22_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P22_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP2_Pos, PORT_P2_PUDEN_PP2_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P22.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P22.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P22_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P22_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP2_Pos, PORT_P2_PUDEN_PP2_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P23.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P23.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P23_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P23_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP3_Pos, PORT_P2_PUDEN_PP3_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P23.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P23.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P23_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P23_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP3_Pos, PORT_P2_PUDEN_PP3_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P24.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P24.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P24_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P24_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP4_Pos, PORT_P2_PUDEN_PP4_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P24.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P24.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P24_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P24_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP4_Pos, PORT_P2_PUDEN_PP4_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P25.
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P25.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P25_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P25_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP5_Pos, PORT_P2_PUDEN_PP5_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P25.
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P25.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P25_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P25_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP5_Pos, PORT_P2_PUDEN_PP5_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P26.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P26.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P26_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P26_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP6_Pos, PORT_P2_PUDEN_PP6_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P26.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P26.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P26_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P26_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP6_Pos, PORT_P2_PUDEN_PP6_Msk, 0u);
}

/** \brief Enable PullUpDown for Port P27.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example enables PullUpDown for Port P27.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P27_PullUpDown_En();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P27_PullUpDown_En(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP7_Pos, PORT_P2_PUDEN_PP7_Msk, 1u);
}

/** \brief Disable PullUpDown for Port P27.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example disables PullUpDown for Port P27.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P27_PullUpDown_Dis();
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P27_PullUpDown_Dis(void)
{
  Field_Mod32(&PORT->P2_PUDEN.reg, (uint8)PORT_P2_PUDEN_PP7_Pos, PORT_P2_PUDEN_PP7_Msk, 0u);
}


/** \brief Set PullUp for Port P20.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P20.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P20_PullUpDown_En();
 *     PORT_P20_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P20_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP0_Pos, PORT_P2_PUDSEL_PP0_Msk, 1u);
}

/** \brief Set PullDown for Port P20.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P20.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P20_PullUpDown_En();
 *     PORT_P20_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P20_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP0_Pos, PORT_P2_PUDSEL_PP0_Msk, 0u);
}

/** \brief Set PullUp for Port P21.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P21.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P21_PullUpDown_En();
 *     PORT_P21_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P21_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP1_Pos, PORT_P2_PUDSEL_PP1_Msk, 1u);
}

/** \brief Set PullDown for Port P21.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P21.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P21_PullUpDown_En();
 *     PORT_P21_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P21_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP1_Pos, PORT_P2_PUDSEL_PP1_Msk, 0u);
}

/** \brief Set PullUp for Port P22.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P22.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P22_PullUpDown_En();
 *     PORT_P22_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P22_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP2_Pos, PORT_P2_PUDSEL_PP2_Msk, 1u);
}

/** \brief Set PullDown for Port P22.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P22.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P22_PullUpDown_En();
 *     PORT_P22_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P22_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP2_Pos, PORT_P2_PUDSEL_PP2_Msk, 0u);
}

/** \brief Set PullUp for Port P23.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P23.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P23_PullUpDown_En();
 *     PORT_P23_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P23_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP3_Pos, PORT_P2_PUDSEL_PP3_Msk, 1u);
}

/** \brief Set PullDown for Port P23.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P23.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P23_PullUpDown_En();
 *     PORT_P23_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P23_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP3_Pos, PORT_P2_PUDSEL_PP3_Msk, 0u);
}

/** \brief Set PullUp for Port P24.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P24.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P24_PullUpDown_En();
 *     PORT_P24_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P24_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP4_Pos, PORT_P2_PUDSEL_PP4_Msk, 1u);
}

/** \brief Set PullDown for Port P24.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P24.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P24_PullUpDown_En();
 *     PORT_P24_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P24_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP4_Pos, PORT_P2_PUDSEL_PP4_Msk, 0u);
}

/** \brief Set PullUp for Port P25.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P25.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P25_PullUpDown_En();
 *     PORT_P25_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P25_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP5_Pos, PORT_P2_PUDSEL_PP5_Msk, 1u);
}

/** \brief Set PullDown for Port P25.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P25.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P25_PullUpDown_En();
 *     PORT_P25_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P25_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP5_Pos, PORT_P2_PUDSEL_PP5_Msk, 0u);
}

/** \brief Set PullUp for Port P26.
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P26.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P26_PullUpDown_En();
 *     PORT_P26_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P26_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP6_Pos, PORT_P2_PUDSEL_PP6_Msk, 1u);
}

/** \brief Set PullDown for Port P26.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P26.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P26_PullUpDown_En();
 *     PORT_P26_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P26_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP6_Pos, PORT_P2_PUDSEL_PP6_Msk, 0u);
}

/** \brief Set PullUp for Port P27.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullUp for Port P27.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P27_PullUpDown_En();
 *     PORT_P27_PullUp_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P27_PullUp_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP7_Pos, PORT_P2_PUDSEL_PP7_Msk, 1u);
}

/** \brief Set PullDown for Port P27.
 *
 * \return None
 *
 * \brief <b>Example</b><br>
 * \brief This example sets PullDown for Port P27.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P27_PullUpDown_En();
 *     PORT_P27_PullDown_Set(); 
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */
INLINE void PORT_P27_PullDown_Set(void)
{
  Field_Mod32(&PORT->P2_PUDSEL.reg, (uint8)PORT_P2_PUDSEL_PP7_Pos, PORT_P2_PUDSEL_PP7_Msk, 0u);
}


#endif /* PORT_H */
