/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/**
 * \file     tle_variants.h
 *
 * \brief    Device specific memory layout defines
 *
 * \version  V0.1.3
 * \date     13. Dec 2021
 */

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V0.1.0: 2019-03-26, JO:   Initial version                                  **
** V0.1.1: 2021-08-16, BG:   EP-731: Updated revision history layout          **
** V0.1.2: 2021-10-07, BG:   EP-931: Added definition of sNADstart to correct **
**                           ARMCC compiler v6 errors in system_tle984x.c     **
** V0.1.3: 2021-12-13, JO:   EP-933: Updated copyright and branding           **
*******************************************************************************/

#ifndef _TLE_VARIANTS_H
#define _TLE_VARIANTS_H

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/

#include "types.h"
#include "RTE_Components.h"

/*******************************************************************************
**                          Global Macro Definitions                          **
*******************************************************************************/
/* Family definitions  */
#define     TLE98     (98)

/* Series definitions  */
#define    TLE984     (984)
#define    TLE985     (985)
#define    TLE986     (986)
#define    TLE987     (987)

/* Device definitions  */
#define    TLE9842    (9842)
#define    TLE9843    (9843)
#define    TLE9844    (9844)
#define    TLE9845    (9845)

/* Package definitions */
#define    BGA144     (1)
#define    LQFP144    (2)
#define    LQFP100    (3)
#define    BGA64      (4)
#define    LQFP64     (5)
#define    VQFN48     (6)
#define    TSSOP38    (7)
#define    TSSOP28    (8)
#define    TSSOP16    (9) 
#define    VQFN24     (10)
#define    VQFN40     (11)

#if defined(TLE9842QX)
#define UC_FAMILY       TLE98
#define UC_SERIES       TLE984
#define UC_DEVICE       TLE9842
#define UC_PACKAGE      VQFN48
#define UC_FLASH        (36UL)
#define UC_FEAT_HS      (1U)
#define UC_FEAT_MON     (4U)
#define ProgFlashSize   (0x8000U)
#define RAMSize         (0x800U)

#elif defined(TLE9842_2QX)
#define UC_FAMILY       TLE98
#define UC_SERIES       TLE984
#define UC_DEVICE       TLE9842
#define UC_PACKAGE      VQFN48
#define UC_FLASH        (40UL)
#define UC_FEAT_HS      (2U)
#define UC_FEAT_MON     (5U)
#define ProgFlashSize   (0x9000U)
#define RAMSize         (0x800U)

#elif defined(TLE9843QX)
#define UC_FAMILY       TLE98
#define UC_SERIES       TLE984
#define UC_DEVICE       TLE9843
#define UC_PACKAGE      VQFN48
#define UC_FLASH        (48UL)
#define UC_FEAT_HS      (1U)
#define UC_FEAT_MON     (4U)
#define ProgFlashSize   (0xB000U)
#define RAMSize         (0x1000U)

#elif defined(TLE9843_2QX)
#define UC_FAMILY       TLE98
#define UC_SERIES       TLE984
#define UC_DEVICE       TLE9843
#define UC_PACKAGE      VQFN48
#define UC_FLASH        (52UL)
#define UC_FEAT_HS      (2U)
#define UC_FEAT_MON     (5U)
#define ProgFlashSize   (0xC000U)
#define RAMSize         (0x1000U)

#elif defined(TLE9844QX)
#define UC_FAMILY       TLE98
#define UC_SERIES       TLE984
#define UC_DEVICE       TLE9844
#define UC_PACKAGE      VQFN48
#define UC_FLASH        (64UL)
#define UC_FEAT_HS      (1U)
#define UC_FEAT_MON     (4U)
#define ProgFlashSize   (0xF000U)
#define RAMSize         (0x1000U)

#elif defined(TLE9844_2QX)
#define UC_FAMILY       TLE98
#define UC_SERIES       TLE984
#define UC_DEVICE       TLE9844
#define UC_PACKAGE      VQFN48
#define UC_FLASH        (64UL)
#define UC_FEAT_HS      (2U)
#define UC_FEAT_MON     (5U)
#define ProgFlashSize   (0xF000U)
#define RAMSize         (0x1000U)

#elif defined(TLE9845QX)
#define UC_FAMILY       TLE98
#define UC_SERIES       TLE984
#define UC_DEVICE       TLE9845
#define UC_PACKAGE      VQFN48
#define UC_FLASH        (48UL)
#define UC_FEAT_HS      (2U)
#define UC_FEAT_MON     (5U)
#define ProgFlashSize   (0xB000U)
#define RAMSize         (0x1000U)

#else
/*lint -e309 */
#error "tle_device.h: device not supported"
/*lint -e309 */
#endif

/* Memory definitions */
#define ProgFlashStart  (0x11000000U)                     /* Start Address of the flash */
#define DataFlashStart  (ProgFlashStart + ProgFlashSize)
#define DataFlashSize   (0x1000U)                         /* 4KB Data Flash             */
#define sNACStart       ".ARM.__at_0x10FFFFFC"
#define NACStart        (ProgFlashStart - 4U)
#define NADStart        (ProgFlashStart - 2U)
#define RAMStart        (0x18000000UL)                    /* Start Address of the SRAM  */


#if (UC_SERIES == 984)
  #include "tle984x.h"
#endif

#endif
