/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/

#include "hs.h"
#include "hs_defines.h"

/*******************************************************************************
**                         Global Function Definitions                        **
*******************************************************************************/

/** \brief Initialize the HS1 module.
 *
 * \ingroup hs_api
 */
void HS1_Init(void)
{
#if ((HS_CTRL & (1u << 0u)) != 0u)
  HS->HS1_TRIM.reg = HS_HS1_TRIM;
  HS->IRQEN.reg = ((HS->IRQEN.reg & 0xFFFF0000u) | (HS_IRQEN & 0x0000FFFFu));
  HS->PWMSRCSEL.reg = ((HS->PWMSRCSEL.reg & 0x0000FFC7u) | (HS_PWMSRCSEL & 0x00000038u));
#if ((HS_CTRL & (1u << 7u)) != 0u)
    PMU->HIGHSIDE_CTRL.bit.HS1_CYC_EN = 1u;
#endif
  HS->CTRL.reg = ((HS->CTRL.reg & 0xFFFF0000u) | (HS_CTRL & 0x0000FFFFu));
#endif
}

#if (UC_FEAT_HS > 1u)
/** \brief Initialize the HS2 module.
 *
 * \ingroup hs_api
 */
void HS2_Init(void)
{
#if ((HS_CTRL & (1u << 16u)) != 0u)	
  HS->HS2_TRIM.reg = HS_HS2_TRIM;
  HS->IRQEN.reg = ((HS->IRQEN.reg & 0x0000FFFFu) | (HS_IRQEN & 0xFFFF0000u));
  HS->PWMSRCSEL.reg = ((HS->PWMSRCSEL.reg & 0x0000FFF8u) | (HS_PWMSRCSEL & 0x00000007u));
#if ((HS_CTRL & (1u << 23u)) != 0u)
    PMU->HIGHSIDE_CTRL.bit.HS2_CYC_EN = 1u;
#endif
  HS->CTRL.reg = ((HS->CTRL.reg & 0x0000FFFFu) | (HS_CTRL & 0xFFFF0000u));
#endif	
}

#endif
