/*
 ***********************************************************************************************************************
 *
 * Copyright (c) Infineon Technologies AG 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                                  Includes                                  **
*******************************************************************************/

#include "port.h"
#include "port_defines.h"

/*******************************************************************************
**                         Global Function Definitions                        **
*******************************************************************************/

/** \brief Initializes the ports.
 *
 * \ingroup port_api
 */
void PORT_Init(void)
{
  /* Initialize all ports */
#if(PORT_XML_VERSION < 10204)
  uint8 Value;

  /* Port 0 */
  PORT->P0_DIR.reg = (uint8) PORT_P0_DIR;

  PORT->P0_OD.reg = (uint8) PORT_P0_OD;

  Value  = (uint8) ((PORT_P0_0_PUD & 0x02u) >> 1u);
  Value |= (uint8) ((PORT_P0_1_PUD & 0x02u));
  Value |= (uint8) ((PORT_P0_2_PUD & 0x02u) << 1u);
  Value |= (uint8) ((PORT_P0_3_PUD & 0x02u) << 2u);
  Value |= (uint8) ((PORT_P0_4_PUD & 0x02u) << 3u);
  Value |= (uint8) ((PORT_P0_5_PUD & 0x02u) << 4u);
  PORT->P0_PUDEN.reg = Value;

  Value  = (uint8) ((PORT_P0_0_PUD & 0x01u));
  Value |= (uint8) ((PORT_P0_1_PUD & 0x01u) << 1u);
  Value |= (uint8) ((PORT_P0_2_PUD & 0x01u) << 2u);
  Value |= (uint8) ((PORT_P0_3_PUD & 0x01u) << 3u);
  Value |= (uint8) ((PORT_P0_4_PUD & 0x01u) << 4u);
  Value |= (uint8) ((PORT_P0_5_PUD & 0x01u) << 5u);
  PORT->P0_PUDSEL.reg = Value;

  Value  = (uint8) ((PORT_P0_0_ALT & 0x01u));
  Value |= (uint8) ((PORT_P0_1_ALT & 0x01u) << 1u);
  Value |= (uint8) ((PORT_P0_2_ALT & 0x01u) << 2u);
  Value |= (uint8) ((PORT_P0_3_ALT & 0x01u) << 3u);
  Value |= (uint8) ((PORT_P0_4_ALT & 0x01u) << 4u);
  Value |= (uint8) ((PORT_P0_5_ALT & 0x01u) << 5u);
  PORT->P0_ALTSEL0.reg = Value;

  Value  = (uint8) ((PORT_P0_0_ALT & 0x02u) >> 1u);
  Value |= (uint8) ((PORT_P0_1_ALT & 0x02u));
  Value |= (uint8) ((PORT_P0_2_ALT & 0x02u) << 1u);
  Value |= (uint8) ((PORT_P0_3_ALT & 0x02u) << 2u);
  Value |= (uint8) ((PORT_P0_4_ALT & 0x02u) << 3u);
  Value |= (uint8) ((PORT_P0_5_ALT & 0x02u) << 4u);
  PORT->P0_ALTSEL1.reg = Value;
	
  PORT->P0_DATA.reg = (uint8) PORT_P0_DATA;
  
  SCU->P0_POCON0.reg = (uint32)SCU_P0_POCON0;

  /* Port 1 */
  PORT->P1_DIR.reg = (uint8) PORT_P1_DIR;
  PORT->P1_OD.reg = (uint8) PORT_P1_OD;

  Value  = (uint8) ((PORT_P1_0_PUD & 0x02u) >> 1u);
  Value |= (uint8) ((PORT_P1_1_PUD & 0x02u));
  Value |= (uint8) ((PORT_P1_2_PUD & 0x02u) << 1u);
  Value |= (uint8) ((PORT_P1_4_PUD & 0x02u) << 3u);
  PORT->P1_PUDEN.reg = Value;

  Value  = (uint8) ((PORT_P1_0_PUD & 0x01u));
  Value |= (uint8) ((PORT_P1_1_PUD & 0x01u) << 1u);
  Value |= (uint8) ((PORT_P1_2_PUD & 0x01u) << 2u);
  Value |= (uint8) ((PORT_P1_4_PUD & 0x01u) << 4u);
  PORT->P1_PUDSEL.reg = Value;

  Value  = (uint8) ((PORT_P1_0_ALT & 0x01u));
  Value |= (uint8) ((PORT_P1_1_ALT & 0x01u) << 1u);
  Value |= (uint8) ((PORT_P1_2_ALT & 0x01u) << 2u);
  Value |= (uint8) ((PORT_P1_4_ALT & 0x01u) << 4u);
  PORT->P1_ALTSEL0.reg = Value;

  Value  = (uint8) ((PORT_P1_0_ALT & 0x02u) >> 1u);
  Value |= (uint8) ((PORT_P1_1_ALT & 0x02u));
  Value |= (uint8) ((PORT_P1_2_ALT & 0x02u) << 1u);
  Value |= (uint8) ((PORT_P1_4_ALT & 0x02u) << 3u);
  PORT->P1_ALTSEL1.reg = Value;

  PORT->P1_DATA.reg = (uint8) PORT_P1_DATA;
  
  SCU->P1_POCON0.reg = (uint32)SCU_P1_POCON0;

  /* Port 2 */
  PORT->P2_DIR.reg = (uint8) PORT_P2_DIR;

  Value  = (uint8) ((PORT_P2_0_PUD & 0x02u) >> 1u);
  Value |= (uint8) ((PORT_P2_1_PUD & 0x02u));
  Value |= (uint8) ((PORT_P2_2_PUD & 0x02u) << 1u);
  Value |= (uint8) ((PORT_P2_3_PUD & 0x02u) << 2u);
  Value |= (uint8) ((PORT_P2_4_PUD & 0x02u) << 3u);
  Value |= (uint8) ((PORT_P2_5_PUD & 0x02u) << 4u);
  Value |= (uint8) ((PORT_P2_6_PUD & 0x02u) << 5u);
  Value |= (uint8) ((PORT_P2_7_PUD & 0x02u) << 6u);
  PORT->P2_PUDEN.reg = Value;

  Value  = (uint8) ((PORT_P2_0_PUD & 0x01u));
  Value |= (uint8) ((PORT_P2_1_PUD & 0x01u) << 1u);
  Value |= (uint8) ((PORT_P2_2_PUD & 0x01u) << 2u);
  Value |= (uint8) ((PORT_P2_3_PUD & 0x01u) << 3u);
  Value |= (uint8) ((PORT_P2_4_PUD & 0x01u) << 4u);
  Value |= (uint8) ((PORT_P2_5_PUD & 0x01u) << 5u);
  Value |= (uint8) ((PORT_P2_6_PUD & 0x01u) << 6u);
  Value |= (uint8) ((PORT_P2_7_PUD & 0x01u) << 7u);
  PORT->P2_PUDSEL.reg = Value;
  
#else

  /* Port 0 */
  PORT->P0_DIR.reg = (uint8)PORT_P0_DIR;
  PORT->P0_OD.reg = (uint8)PORT_P0_OD;
  PORT->P0_PUDEN.reg = (uint8)PORT_P0_PUDEN;
  PORT->P0_PUDSEL.reg = (uint8)PORT_P0_PUDSEL;
  PORT->P0_ALTSEL0.reg = (uint8)PORT_P0_ALTSEL0;
  PORT->P0_ALTSEL1.reg = (uint8)PORT_P0_ALTSEL1;
  PORT->P0_DATA.reg = (uint8)PORT_P0_DATA;
  SCU->P0_POCON0.reg = (uint32)SCU_P0_POCON0;

  /* Port 1 */
  PORT->P1_DIR.reg = (uint8)PORT_P1_DIR;
  PORT->P1_OD.reg = (uint8)PORT_P1_OD;
  PORT->P1_PUDEN.reg = (uint8)PORT_P1_PUDEN;
  PORT->P1_PUDSEL.reg = (uint8)PORT_P1_PUDSEL;
  PORT->P1_ALTSEL0.reg = (uint8)PORT_P1_ALTSEL0;
  PORT->P1_ALTSEL1.reg = (uint8)PORT_P1_ALTSEL1;
  PORT->P1_DATA.reg = (uint8)PORT_P1_DATA;
  SCU->P1_POCON0.reg = (uint32)SCU_P1_POCON0;

  /* Port 2 */
  PORT->P2_DIR.reg = (uint8)PORT_P2_DIR;
  PORT->P2_PUDEN.reg = (uint8)PORT_P2_PUDEN;
  PORT->P2_PUDSEL.reg = (uint8)PORT_P2_PUDSEL;

#endif

}

/** \brief Set/clear/toggle a port pin in a safe way, i.e. with interrupt disable.
 *
 * \param PortPin Port and pin to change, e.g 0x12U for P1.2
 * \param Action PORT_ACTION_SET, PORT_ACTION_CLEAR or PORT_ACTION_TOGGLE
 *
 * \brief <b>Example</b><br>
 * \brief This example toggles the P1.2 .
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_ChangePin(0x12, PORT_ACTION_TOGGLE);
 * }
 * ~~~~~~~~~~~~~~~ 
 * \ingroup port_api
 */ 
void PORT_ChangePin(uint32 PortPin, uint32 Action)
{
  sint32 int_was_mask;
  volatile uint32 *pSfr;
  uint32 PinMask;
  uint8  PinPos;
  uint32 addr;
  uint16 idx;

  /* Pin pos */
  PinPos = (uint8)(PortPin & 0x7U);
  /* Pin mask = 1 shifted left by pin */
  PinMask = ((uint32)1U << PinPos);

  /* DATA pointer = address of P0_DATA + port * 32 */
  /* 0x20 Bytes Offset between the Px_DATA registers */
  addr = (uint32)&PORT->P0_DATA.reg;

  idx = (uint16)((PortPin >> 4U) << 5U);

  addr += idx;

  pSfr = (volatile uint32 *) addr;

  /* Change DATA register according to Action */
  int_was_mask = CMSIS_Irq_Dis();
  if (Action == PORT_ACTION_CLEAR)
  {
    Field_Clr32(pSfr, PinMask);
  }
  else if (Action == PORT_ACTION_SET)
  {
    Field_Mod32(pSfr, PinPos, PinMask, 1u);
  }
  else if (Action == PORT_ACTION_TOGGLE)
  {
    Field_Inv32(pSfr, PinMask);
  }
  else if (Action == PORT_ACTION_INPUT)
  {
    addr = (uint32)&PORT->P0_DIR.reg;

    idx = (uint16)((PortPin >> 4U) << 5U);

    addr += idx;

    pSfr = (volatile uint32 *) addr;
    Field_Clr32(pSfr, PinMask);
  }
  else                          /* (Action == PORT_ACTION_OUTPUT) */
  {
    addr = (uint32)&PORT->P0_DIR.reg;

    idx = (uint16)((PortPin >> 4U) << 5U);

    addr += idx;

    pSfr = (volatile uint32 *) addr;
    Field_Mod32(pSfr, PinPos, PinMask, 1u);
  }
  if (int_was_mask == 0)
  {
    CMSIS_Irq_En();
  }
}

/** \brief Read a port pin.
 *
 * \param PortPin Port and pin to read, e.g 0x12U for P1.2
 * \return Port pin level (0U or 1U)
 *
 * \brief <b>Example</b><br>
 * \brief This example reads the status of P1.2 .
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint32 sts;
 * 
 *     sts = PORT_ReadPin(0x12);
 * }
 * ~~~~~~~~~~~~~~~  
 * \ingroup port_api
 */ 
uint32 PORT_ReadPin(uint32 PortPin)
{
  const volatile uint32 *pSfr;
  uint32 PinMask;
  uint8 PinPos;
  uint32 addr;
  uint16 idx;

  /* Pin pos */
  PinPos = (uint8)(PortPin & 0x7U);
  /* Pin mask = 1 shifted left by pin */
  PinMask = ((uint32)1U << PinPos);
  /* DATA pointer = address of P0_DATA + port * 8 */
  /* violation: cast from pointer to unsigned int [MISRA Rule 45]*/
  addr = (uint32)&PORT->P0_DATA.reg;
  
  idx = (uint16)((PortPin >> 4U) << 5U);
  
  addr += idx;
  pSfr = (volatile uint32 *) addr;

  /* Read DATA register, shift right by pin and extract bit 0 */
  return (u32_Field_Rd32(pSfr, PinPos, PinMask) );
}

/** \brief Read a port.
 *
 * \param Port Port to read, e.g. 2U for Port 2
 * \return Port data (combination of 0Us and 1Us)
 *
 * \brief <b>Example</b><br>
 * \brief This example reads the status of Port2 .
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     uint32 sts;
 * 
 *     sts = PORT_ReadPort(0x2);
 * }
 * ~~~~~~~~~~~~~~~  
 * \ingroup port_api
 */ 
uint32 PORT_ReadPort(uint32 Port)
{
  const volatile uint32 *pSfr;
  uint32 addr;
  uint16 idx;

  /* DATA pointer = address of P0_DATA + port * 32 */
  addr = (uint32)&PORT->P0_DATA.reg;
  
  idx = (uint16)(Port << 5U);
  
  addr += idx;
  
  /* violation: cast from unsigned int to pointer [MISRA Rule 45]*/
  pSfr = (volatile uint32 *) addr;

  /* Read DATA register */
  //return *pSfr;
  return (u8_Field_Rd32(pSfr, 0, 0xFF));
}

/** \brief Change Alternate Settings.
 *
 * \param PortPin pin to change AltSel, e.g. 0x01U for Port 0 Pin 1
 * \param AltSel alternate function for the pin (combination of 0Us and 1Us)
 *
 * \brief <b>Example</b><br>
 * \brief This example sets the P1.2 to Output and configures it to Normal GPIO.
 * ~~~~~~~~~~~~~~~{.c}
 * void Example_Function(void)
 * {
 *     PORT_P12_Output_Set();
 *     PORT_ChangePinAlt(0x12, 0u);
 * }
 * ~~~~~~~~~~~~~~~  
 * \ingroup port_api
 */ 

void PORT_ChangePinAlt(uint32 PortPin, uint32 AltSel)
{
  sint32 int_was_mask;
  volatile uint32 *pSfr0, *pSfr1;
  uint32 PinMask;
  uint8  PinPos;
  uint32 addr;
  uint16 idx;

  /* Pin pos */
  PinPos = (uint8)(PortPin & 0x7U);
  /* Pin mask = 1 shifted left by pin */
  PinMask = ((uint32)1U << PinPos);

  /* DATA pointer = address of P0_DATA + port * 32 */
  /* violation: cast from pointer to unsigned int [MISRA Rule 45]*/
  addr = (uint32)&PORT->P0_ALTSEL0.reg;
  
  idx = (uint16)((PortPin >> 4U) << 5U);
  
  addr += idx;
  
  /* violation: cast from unsigned int to pointer [MISRA Rule 45]*/
  pSfr0 = (volatile uint32 *) addr;

  /* violation: cast from pointer to unsigned int [MISRA Rule 45]*/
  addr = (uint32)&PORT->P0_ALTSEL1.reg;
  
  idx = (uint16)((PortPin >> 4U) << 5U);  

  addr += idx;

  pSfr1 = (volatile uint32 *) addr;

  /* Change DATA register according to Action */
  int_was_mask = CMSIS_Irq_Dis();

  Field_Mod32(pSfr0, PinPos, PinMask, (AltSel & 1u));
  Field_Mod32(pSfr1, PinPos, PinMask, ((AltSel >> 1u) & 1u));

  if (int_was_mask == 0)
  {
    CMSIS_Irq_En();
  }
}
